import { exportDataGrid as exportToExcel } from 'devextreme/excel_exporter'
import { saveAs } from 'file-saver'
import { jsPDF } from 'jspdf'
import autoTable from 'jspdf-autotable'
import { Workbook } from 'exceljs'
import { formatWaktu } from '@/components/Form/FiltersType/reference'
import { setHeaderStyle } from '@/report/utils/xlsx'
import { formatNumber, formatPercentage } from '@/utils/numbers'
import { exportToWord, exportDetailToWord } from './doc/Anomali_LAPPGU_LPT'

const reportName = 'Anomali Penanganan Pengaduan Gangguan Unit'
const fontSize = 5
const detailFontSize = 3

const formatData = (rawData: any) => {
  const formattedData: any = []
  const total: any = {
    wo_cc123: 0,
    wo_pln_mobile: 0,
    wo_loket: 0,
    wo_lainnya: 0,
    // wo_total
    anomali_pln_mobile_marking: 0,
    anomali_pln_mobile_non_marking: 0,
    anomali_cc123_marking: 0,
    anomali_cc123_non_marking: 0
    // total_anomali_marking
    // total_anomali_non_marking
    // persen_anomali_pln_mobile_marking
    // persen_anomali_pln_mobile_non_marking
    // persen_anomali_cc123_marking
    // persen_anomali_cc123_non_marking
    // persen_anomali_marking
    // persen_anomali_non_marking
  }

  rawData.forEach((item: any) => {
    total.wo_cc123 += item.wo_cc123
    total.wo_pln_mobile += item.wo_pln_mobile
    total.wo_loket += item.wo_loket
    total.wo_lainnya += item.wo_lainnya
    total.anomali_pln_mobile_marking += item.anomali_pln_mobile_marking
    total.anomali_pln_mobile_non_marking += item.anomali_pln_mobile_non_marking
    total.anomali_cc123_marking += item.anomali_cc123_marking
    total.anomali_cc123_non_marking += item.anomali_cc123_non_marking
  })

  const wo_total = total.wo_cc123 + total.wo_pln_mobile + total.wo_loket + total.wo_lainnya
  const total_anomali_marking = total.anomali_pln_mobile_marking + total.anomali_cc123_marking
  const total_anomali_non_marking =
    total.anomali_pln_mobile_non_marking + total.anomali_cc123_non_marking
  const persen_anomali_pln_mobile_marking = total.anomali_pln_mobile_marking / wo_total
  const persen_anomali_pln_mobile_non_marking = total.anomali_pln_mobile_non_marking / wo_total
  const persen_anomali_cc123_marking = total.anomali_cc123_marking / wo_total
  const persen_anomali_cc123_non_marking = total.anomali_cc123_non_marking / wo_total
  const persen_anomali_marking = persen_anomali_pln_mobile_marking + persen_anomali_cc123_marking
  const persen_anomali_non_marking =
    persen_anomali_pln_mobile_non_marking + persen_anomali_cc123_non_marking

  formattedData.push([
    'Semua Unit',
    formatNumber(total.wo_cc123),
    formatNumber(total.wo_pln_mobile),
    formatNumber(total.wo_loket),
    formatNumber(total.wo_lainnya),
    formatNumber(wo_total),
    formatNumber(total.anomali_pln_mobile_marking),
    formatNumber(total.anomali_pln_mobile_non_marking),
    formatNumber(total.anomali_cc123_marking),
    formatNumber(total.anomali_cc123_non_marking),
    formatNumber(total_anomali_marking),
    formatNumber(total_anomali_non_marking),
    formatPercentage(
      !persen_anomali_pln_mobile_marking || !isFinite(persen_anomali_pln_mobile_marking)
        ? 0
        : persen_anomali_pln_mobile_marking * 100
    ),
    formatPercentage(
      !persen_anomali_pln_mobile_non_marking || !isFinite(persen_anomali_pln_mobile_non_marking)
        ? 0
        : persen_anomali_pln_mobile_non_marking * 100
    ),
    formatPercentage(
      !persen_anomali_cc123_marking || !isFinite(persen_anomali_cc123_marking)
        ? 0
        : persen_anomali_cc123_marking * 100
    ),
    formatPercentage(
      !persen_anomali_cc123_non_marking || !isFinite(persen_anomali_cc123_non_marking)
        ? 0
        : persen_anomali_cc123_non_marking * 100
    ),
    formatPercentage(
      !persen_anomali_marking || !isFinite(persen_anomali_marking)
        ? 0
        : persen_anomali_marking * 100
    ),
    formatPercentage(
      !persen_anomali_non_marking || !isFinite(persen_anomali_non_marking)
        ? 0
        : persen_anomali_non_marking * 100
    )
  ])

  return formattedData
}

const formatMetaData = (reportMeta: any) => {
  const periode = reportMeta.periode ? reportMeta.periode.split(' s/d ') : ''

  let dateFromFormat = ''
  let dateToFormat = ''
  let dayTo = ''

  if (periode != '') {
    const dateFrom = new Date(periode[0].split('-').reverse().join('-'))
    const dateTo = new Date(periode[1].split('-').reverse().join('-'))

    dateFromFormat = `${dateFrom.getDate()}-${dateFrom.toLocaleString('id-ID', {
      month: 'long'
    })}-${dateFrom.getFullYear()}`

    dateToFormat = `${dateTo.getDate()}-${dateTo.toLocaleString('id-ID', {
      month: 'long'
    })}-${dateTo.getFullYear()}`

    dayTo = dateTo.toLocaleString('id-ID', { weekday: 'long' })
  }

  return { dateFromFormat, dateToFormat, dayTo }
}

const exportToPDF = (reportMeta: any, rawData: any, preview: boolean = false) => {
  const data = formatData(rawData)
  const meta = formatMetaData(reportMeta)
  const doc = new jsPDF({
    orientation: 'landscape'
  })

  autoTable(doc, {
    head: [
      ['PT. PLN(Persero)', '', ''],
      [
        { content: 'UNIT INDUK', styles: { cellWidth: 40 } },
        { content: ':', styles: { cellWidth: 1 } },
        reportMeta.uid
          ? reportMeta.uid.name.toUpperCase()
          : 'Semua Unit Induk Distribusi/Wilayah'.toUpperCase()
      ],
      [
        'UNIT PELAKSANA PELAYANAN PELANGGAN',
        ':',
        reportMeta.up3
          ? reportMeta.up3.name.toUpperCase()
          : 'Semua Unit Pelaksanaan Pelayanan Pelanggan'.toUpperCase()
      ],
      [
        'UNIT LAYANAN PELANGGAN',
        ':',
        reportMeta.ulp
          ? reportMeta.ulp.name.toUpperCase()
          : 'Semua Unit Layanan Pelanggan'.toUpperCase()
      ],
      ['JENIS LAPORAN', ':', reportMeta.jenisLaporan.name.toUpperCase()]
    ],
    styles: {
      fontSize,
      cellPadding: 0.1,
      textColor: [0, 0, 0],
      fontStyle: 'bold'
    },
    theme: 'plain',
    startY: 10
  })

  autoTable(doc, {
    head: [
      [`${reportName}`.toUpperCase()],
      [`PERIODE TANGGAL : ${meta.dateFromFormat} SD TGL ${meta.dateToFormat}`]
    ],
    styles: {
      fontSize,
      cellPadding: 0.1,
      textColor: [0, 0, 0],
      fontStyle: 'bold',
      halign: 'center'
    },
    theme: 'plain',
    startY: 25
  })

  autoTable(doc, {
    head: [
      [
        {
          content: 'Nama Unit',
          rowSpan: 4
        },
        {
          content: 'Total WO',
          colSpan: 5
        },
        {
          content: 'Total Pengaduan Yang Diselesaikan Secara Anomali',
          colSpan: 6
        },
        {
          content: '% Pengaduan Yang Diselesaikan Secara Anomali',
          colSpan: 6
        }
      ],
      [
        'CC 123',
        'PLN Mobile',
        'Loket',
        'Lainnya',
        'Total',
        {
          content: 'PLN Mobile',
          colSpan: 2
        },
        {
          content: 'CC 123',
          colSpan: 2
        },
        {
          content: 'Total',
          colSpan: 2
        },
        {
          content: 'PLN Mobile',
          colSpan: 2
        },
        {
          content: 'CC 123',
          colSpan: 2
        },
        {
          content: 'Total',
          colSpan: 2
        }
      ],
      [
        {
          content: 'a',
          rowSpan: 2
        },
        {
          content: 'b',
          rowSpan: 2
        },
        {
          content: 'c',
          rowSpan: 2
        },
        {
          content: 'd',
          rowSpan: 2
        },
        {
          content: 'e=a+b+c+d',
          rowSpan: 2
        },
        {
          content: 'f',
          colSpan: 2
        },
        {
          content: 'g',
          colSpan: 2
        },
        {
          content: 'h=f+g',
          colSpan: 2
        },
        {
          content: 'i=f/e',
          colSpan: 2
        },
        {
          content: 'j=g/e',
          colSpan: 2
        },
        {
          content: 'k=i+j',
          colSpan: 2
        }
      ],
      [
        'Marking',
        'Non Marking',
        'Marking',
        'Non Marking',
        'Marking',
        'Non Marking',
        'Marking',
        'Non Marking',
        'Marking',
        'Non Marking',
        'Marking',
        'Non Marking'
      ]
    ],
    body: data,
    styles: {
      fontSize,
      cellPadding: 1,
      lineColor: [0, 0, 0],
      lineWidth: 0.1,
      cellWidth: 'auto'
    },
    rowPageBreak: 'auto',
    headStyles: {
      fillColor: [192, 192, 192],
      textColor: [0, 0, 0],
      fontStyle: 'bold',
      halign: 'center',
      valign: 'middle'
    },
    bodyStyles: {
      textColor: [0, 0, 0]
    },
    didParseCell: function (data) {
      if (data.row.section === 'head') {
        data.cell.text = data.cell.text.map(function (word: any) {
          return word.toUpperCase()
        })
      }

      if (data.cell.text[0] === 'TOTAL') {
        for (const key in data.row.cells) {
          data.row.cells[key].styles.fillColor = [192, 192, 192]
          data.row.cells[key].styles.fontStyle = 'bold'
        }
      }
    },
    startY: 35
  })

  autoTable(doc, {
    head: [
      [`${meta.dayTo}, ${meta.dateToFormat}`],
      [
        {
          content: '(.........................................)',
          styles: { minCellHeight: 8, valign: 'bottom' }
        }
      ]
    ],
    styles: {
      fontSize,
      cellPadding: 0.1,
      textColor: [0, 0, 0],
      fontStyle: 'bold',
      halign: 'center'
    },
    theme: 'plain',
    tableWidth: 50,
    margin: { left: 230 }
  })

  if (preview) {
    doc.setProperties({
      title: `${reportName}`
    })
    window.open(doc.output('bloburl'))
  } else {
    doc.save(`Laporan ${reportName}.pdf`, { returnPromise: true }).then(() => {
      console.log('pdf berhasil disimpan')
    })
  }
}

const exportDetailToPDF = (reportMeta: any, rawData: any) => {
  const meta = formatMetaData(reportMeta)
  const doc = new jsPDF({
    orientation: 'landscape'
  })

  autoTable(doc, {
    head: [['PT. PLN(Persero)']],
    styles: {
      fontSize: detailFontSize,
      cellPadding: 0.1,
      textColor: [0, 0, 0],
      fontStyle: 'bold'
    },
    theme: 'plain',
    startY: 10,
    margin: 5
  })

  autoTable(doc, {
    head: [
      [`Daftar Detail ${reportName}`.toUpperCase()],
      [`PERIODE TANGGAL : ${meta.dateFromFormat} SD TGL ${meta.dateToFormat}`]
    ],
    styles: {
      fontSize: detailFontSize,
      cellPadding: 0.1,
      textColor: [0, 0, 0],
      fontStyle: 'bold',
      halign: 'center'
    },
    theme: 'plain',
    startY: 18,
    margin: 5
  })

  autoTable(doc, {
    head: [
      [
        'No',
        'UIW/D',
        'UP3',
        'Rayon',
        'No Laporan',
        'No Laporan Referensi',
        'Tgl/Jam Lapor',
        'Tgl/Jam Datang',
        'Tgl/Jam Nyala',
        'Durasi Response Time',
        'Durasi Recovery Time',
        'Durasi Penugasan Regu',
        'Durasi Perjalanan Regu',
        'Jarak Closing',
        'Dispacth Oleh',
        'IDPEL/NO METER',
        'Nama Pelapor',
        'Alamat Pelapor',
        'No Telp Pelapor',
        'Keterangan Pelapor',
        'Sumber Lapor',
        'Diselesaikan Oleh',
        'Status',
        'Status Induk',
        'Referensi Marking Induk',
        'Kode Gangguan',
        'Jenis Gangguan',
        'Penyebab',
        'Tindakan'
      ]
    ],
    body: rawData.map((item: any, i: any) => [
      { content: i + 1, styles: { halign: 'right' } },
      item.nama_uid,
      item.nama_up3,
      item.nama_ulp,
      item.no_laporan,
      item.no_laporan_referensi,
      item.waktu_lapor,
      item.waktu_response,
      item.waktu_recovery,
      item.durasi_response_time ? formatWaktu(item.durasi_response_time) : '-',
      item.durasi_recovery_time ? formatWaktu(item.durasi_recovery_time) : '-',
      item.durasi_dispatch_time ? formatWaktu(item.durasi_dispatch_time) : '-',
      item.durasi_perjalanan ? formatWaktu(item.durasi_perjalanan) : '-',
      item.distance,
      item.dispatch_by,
      item.idpel_nometer,
      item.nama_pelapor,
      item.alamat_pelapor,
      item.no_telp_pelapor,
      item.keterangan_pelapor,
      item.media,
      item.diselesaikan_oleh,
      item.status_akhir,
      item.status_induk,
      item.referensi_marking_induk,
      item.kode_gangguan,
      item.jenis_gangguan,
      item.penyebab,
      item.tindakan
    ]),
    styles: {
      fontSize: detailFontSize,
      cellPadding: 1,
      lineColor: [0, 0, 0],
      lineWidth: 0.1,
      cellWidth: 'auto'
    },
    rowPageBreak: 'auto',
    headStyles: {
      fillColor: [192, 192, 192],
      textColor: [0, 0, 0],
      fontStyle: 'bold',
      halign: 'center',
      valign: 'middle'
    },
    bodyStyles: {
      textColor: [0, 0, 0]
    },
    didParseCell: function (data) {
      if (data.row.section === 'head') {
        data.cell.text = data.cell.text.map(function (word: any) {
          return word.toUpperCase()
        })
      }
    },
    startY: 24,
    margin: 5
  })

  autoTable(doc, {
    head: [
      [`${meta.dayTo}, ${meta.dateToFormat}`],
      [
        {
          content: '(.........................................)',
          styles: { minCellHeight: 8, valign: 'bottom' }
        }
      ]
    ],
    styles: {
      fontSize: detailFontSize,
      cellPadding: 0.1,
      textColor: [0, 0, 0],
      fontStyle: 'bold',
      halign: 'center'
    },
    theme: 'plain',
    tableWidth: 50,
    margin: { left: 230 }
  })

  doc.save(`Laporan Detail ${reportName}.pdf`, { returnPromise: true }).then(() => {
    console.log('pdf berhasil disimpan')
  })
}

const exportToXLSX = (reportMeta: any, e: any) => {
  const meta = formatMetaData(reportMeta)
  const workbook = new Workbook()
  const worksheet = workbook.addWorksheet(`${reportName}`)

  setHeaderStyle(worksheet, 1, 1, 'PT. PLN(Persero)')
  setHeaderStyle(
    worksheet,
    2,
    1,
    `UNIT INDUK : ${
      reportMeta.uid
        ? reportMeta.uid.name.toUpperCase()
        : 'Semua Unit Induk Distribusi/Wilayah'.toUpperCase()
    }`
  )
  setHeaderStyle(
    worksheet,
    3,
    1,
    `UNIT PELAKSANA PELAYANAN PELANGGAN : ${
      reportMeta.up3
        ? reportMeta.up3.name.toUpperCase()
        : 'Semua Unit Pelaksanaan Pelayanan Pelanggan'.toUpperCase()
    }`
  )
  setHeaderStyle(
    worksheet,
    4,
    1,
    `UNIT LAYANAN PELANGGAN : ${
      reportMeta.ulp
        ? reportMeta.ulp.name.toUpperCase()
        : 'Semua Unit Layanan Pelanggan'.toUpperCase()
    }`
  )
  setHeaderStyle(worksheet, 5, 1, `JENIS LAPORAN : ${reportMeta.jenisLaporan.name.toUpperCase()}`)

  setHeaderStyle(worksheet, 7, 1, `${reportName}`.toUpperCase(), true)
  setHeaderStyle(
    worksheet,
    8,
    1,
    `PERIODE TANGGAL : ${meta.dateFromFormat} SD TGL ${meta.dateToFormat}`,
    true
  )

  worksheet.mergeCells('A1:R1')
  worksheet.mergeCells('A2:R2')
  worksheet.mergeCells('A3:R3')
  worksheet.mergeCells('A4:R4')
  worksheet.mergeCells('A5:R5')
  worksheet.mergeCells('A7:R7')
  worksheet.mergeCells('A8:R8')

  exportToExcel({
    component: e.component,
    worksheet,
    autoFilterEnabled: true,
    topLeftCell: { row: 10, column: 1 },
    loadPanel: {
      enabled: false
    }
  }).then(() => {
    workbook.xlsx.writeBuffer().then((buffer: any) => {
      saveAs(new Blob([buffer], { type: 'application/octet-stream' }), `Laporan ${reportName}.xlsx`)
    })
  })

  e.cancel = true
}

const exportDetailToXLSX = (reportMeta: any, e: any) => {
  const meta = formatMetaData(reportMeta)
  const workbook = new Workbook()
  const worksheet = workbook.addWorksheet(`Detail ${reportName}`)

  setHeaderStyle(worksheet, 1, 1, 'PT. PLN(Persero)')
  setHeaderStyle(worksheet, 3, 1, `Daftar Detail ${reportName}`.toUpperCase(), true)
  setHeaderStyle(
    worksheet,
    4,
    1,
    `PERIODE TANGGAL : ${meta.dateFromFormat} SD TGL ${meta.dateToFormat}`,
    true
  )

  worksheet.mergeCells('A1:AC1')
  worksheet.mergeCells('A3:AC3')
  worksheet.mergeCells('A4:AC4')

  exportToExcel({
    component: e.component,
    worksheet,
    autoFilterEnabled: true,
    topLeftCell: { row: 6, column: 1 },
    loadPanel: {
      enabled: false
    }
  }).then(() => {
    workbook.xlsx.writeBuffer().then((buffer: any) => {
      saveAs(
        new Blob([buffer], { type: 'application/octet-stream' }),
        `Laporan Detail ${reportName}.xlsx`
      )
    })
  })

  e.cancel = true
}

const exportToDOCX = (reportMeta: any, rawData: any) => {
  const meta = formatMetaData(reportMeta)
  exportToWord(reportMeta, meta, formatData(rawData), reportName)
}

const exportDetailToDOCX = (reportMeta: any, rawData: any) => {
  const meta = formatMetaData(reportMeta)
  exportDetailToWord(meta, rawData, reportName)
}

export {
  exportToPDF,
  exportToXLSX,
  exportDetailToPDF,
  exportDetailToXLSX,
  exportToDOCX,
  exportDetailToDOCX
}
