import { numberToStars } from "@/report/utils/rating";

const company = "PT. PLN (Persero)";
const exportToWord = (reportMeta: any, rawData: any, filename: any, periode: any) => {
  var preHtml = `<html xmlns:o='urn:schemas-microsoft-com:office:office' xmlns:w='urn:schemas-microsoft-com:office:word' xmlns='http://www.w3.org/TR/REC-html40'><head><meta charset='utf-8'><title>${filename}</title>
    <style type="text/css" media="print">
      @page Section1 {
          size:841.95pt 21.0cm;
          mso-page-orientation:landscape;
          margin:72.0pt 72.0pt 72.0pt 72.0pt;
          mso-header-margin:35.4pt;
          mso-footer-margin:35.4pt;
          mso-paper-source:0;
      }
      @page{
        size: landscape;
        font-size: 5px;
      }
      div.Section1 {
        page:Section1;
      }
      table.main {
        border-collapse: collapse;
        width: 100%;
        text-transform: uppercase;
        font-size: 8px;
      }
      table.main thead tr {
        background-color: #c0c0c0;
      }
  </style>
    </head><body>
   <div class="Section1">
   `;
  var tbody = '';
  for (let index = 0; index < rawData.length; index++) {
    const element = rawData[index];
    var column = '<tr>';
    let styleTotal = '';
    for (let i = 0; i < element.length; i++) {
      const content = element[i];
      const colSpan = content?.colSpan !== undefined ? `colspan="${content.colSpan}"` : ''

      if (content && (content.content === 'TOTAL' || content.content === 'GRAND TOTAL')) {
        styleTotal = 'style="background-color: #c0c0c0; font-weight: bold;"'
      }
      i === 0 ?
        column += `<td ${styleTotal} ${colSpan} align="left">${content.content}</td>`
        : column += `<td ${styleTotal}>${content}</td>`;
    }
    column += '</tr>';
    tbody += column;
  }
  var columnHeader = `<thead>
  <tr>
  <th rowspan="3">No</th>
  <th rowspan="3">Kode</th>
  <th rowspan="3">Nama Regu</th>
  <th colspan="5">Laporan</th>
  <th colspan="7">Rating</th>
  <th colspan="2">Non Rating</th>
</tr>
<tr>
  <th rowspan="2">Total</th>
  <th colspan="2">Belum Selesai</th>
  <th colspan="2">Sudah Selesai</th>
  <th colspan="7">Bintang</th>
  <th rowspan="2">Jml</th>
  <th rowspan="2">%</th>
</tr>
<tr>
  <th>Jml</th>
  <th>%</th>
  <th>Jml</th>
  <th>%</th>
  <th>Jml</th>
  <th>1</th>
  <th>2</th>
  <th>3</th>
  <th>4</th>
  <th>5</th>
  <th>Index</th>
</tr>
</thead>
`;
  var body = `
    <table border=0 style="border:none">
    <tr>
        <td colspan="3"> ${company.toUpperCase()}</td>
    </tr>
    <tr>
      <td> Unit Induk Distribusi/Wilayah  </td>
      <td>:</td>
      <td> ${reportMeta.uid
      ? reportMeta.uid.name.toUpperCase()
      : 'Semua Unit Induk Distribusi/Wilayah'.toUpperCase()}</td>
    <tr>
      <td> Unit Pelaksanaan Pelayanan Pelanggan</td>
      <td>:</td>
      <td>  ${reportMeta.up3
      ? reportMeta.up3.name.toUpperCase()
      : 'Semua Unit Pelaksanaan Pelayanan Pelanggan'.toUpperCase()}</td>
    </tr>
    <tr>
      <td> Posko</td>
      <td>:</td>
      <td> ${reportMeta.posko ? reportMeta.posko.name.toUpperCase() : 'Semua Posko'.toUpperCase()}</td>
    </tr>
    </table>
    <center><h6>${filename.toUpperCase()}</h6></center>
    <center><h6>Periode : ${periode.dateFromFormat} s/d ${periode.dateToFormat} (${periode.dayTo})<h6></center>
    <table class="main">
          ${columnHeader}
    <tbody>
    ${tbody} 
    </tbody>
    </table>
   `

  var postHtml = `<br>
      <footer>
        <p style="text-align: right; font-size: 10px;">${periode.dayTo}, ${periode.dateToFormat}</p>
        <br>
        <p style="text-align: right; font-size: 10px;">(.........................................)</p>
      </footer></div></body></html>`;

  var html = preHtml + body + postHtml;

  var url =
    "data:application/vnd.ms-word;charset=utf-8," + encodeURIComponent(html);

  filename = filename ? filename + ".doc" : "document.doc";

  var downloadLink = document.createElement("a");

  document.body.appendChild(downloadLink);

  downloadLink.href = url;

  downloadLink.download = filename;

  downloadLink.click();

  document.body.removeChild(downloadLink);
}

const exportDetailToWord = (reportMeta: any, rawData: any, filename: any, periode: any) => {
  var preHtml = `<html xmlns:o='urn:schemas-microsoft-com:office:office' xmlns:w='urn:schemas-microsoft-com:office:word' xmlns='http://www.w3.org/TR/REC-html40'><head><meta charset='utf-8'><title>${filename}</title>
    <style type="text/css" media="print">
      @page Section1 {
          size:841.95pt 21.0cm;
          mso-page-orientation:landscape;
          margin:72.0pt 72.0pt 72.0pt 72.0pt;
          mso-header-margin:35.4pt;
          mso-footer-margin:35.4pt;
          mso-paper-source:0;
      }
      @page{
        size: landscape;
        font-size: 5px;
      }
      div.Section1 {
        page:Section1;
      }
      table.main {
        border-collapse: collapse;
        width: 100%;
        text-transform: uppercase;
        font-size: 8px;
      }
      table.main thead tr {
        background-color: #c0c0c0;
      }
  </style>
    </head><body>
   <div class="Section1">
   `;
  var tbody = ``;
  var cr = ``;
  rawData.map((item: any, i: any) => {
    cr += '<tr>';
    cr += `<td>${i + 1}</td>`;
    cr += `<td>${item.no_laporan}</td>`;
    cr += `<td>${numberToStars(item.nilai_rating)}</td>`;
    cr += `<td>${item.waktu_lapor}</td>`;
    cr += `<td>${item.waktu_response}</td>`;
    cr += `<td>${item.waktu_recovery}</td>`;
    cr += `<td>${item.durasi_response_time}</td>`;
    cr += `<td>${item.durasi_recovery_time}</td>`;
    cr += `<td>${item.status_akhir}</td>`;
    cr += `<td>${item.referensi_marking}</td>`;
    cr += `<td>${item.idpel_nometer}</td>`;
    cr += `<td>${item.nama_pelapor}</td>`;
    cr += `<td>${item.alamat_pelapor}</td>`;
    cr += `<td>${item.no_telp_pelapor}</td>`;
    cr += `<td>${item.keterangan_pelapor}</td>`;
    cr += `<td>${item.nama_posko}</td>`;
    cr += `<td>${item.tindakan}</td>`;
    cr += `<td>${item.penyebab}</td>`;
    cr += '</tr>';
  });
  tbody += cr;

  var body = `
    <table border=0 style="border:none">
    <tr>
        <td colspan="3"> ${company.toUpperCase()}</td>
    </tr>
    <tr>
      <td> Unit Induk Distribusi/Wilayah  </td>
      <td>:</td>
      <td> ${reportMeta.uid
      ? reportMeta.uid.name.toUpperCase()
      : 'Semua Unit Induk Distribusi/Wilayah'.toUpperCase()}</td>
    <tr>
      <td> Unit Pelaksanaan Pelayanan Pelanggan</td>
      <td>:</td>
      <td>  ${reportMeta.up3
      ? reportMeta.up3.name.toUpperCase()
      : 'Semua Unit Pelaksanaan Pelayanan Pelanggan'.toUpperCase()}</td>
    </tr>
    <tr>
      <td> Posko</td>
      <td>:</td>
      <td> ${reportMeta.posko ? reportMeta.posko.name.toUpperCase() : 'Semua Posko'.toUpperCase()}</td>
    </tr>
    </table>
    <center><h6>${filename.toUpperCase()}</h6></center>
    <center><h6>Periode : ${periode.dateFromFormat} s/d ${periode.dateToFormat} (${periode.dayTo})<h6></center>
    <table class="main">
       <thead>
       <tr>
        <td>No</td>
        <td>No Laporan</td>
        <td>Rating</td>
        <td>Tgl Lapor</td>
        <td>Tgl Datang</td>
        <td>Tgl Nyala</td>
        <td>Durasi Response Time</td>
        <td>Durasi Recovery Time</td>
        <td>Status</td>
        <td>Referensi Marking</td>
        <td>IDPEL/NO METER</td>
        <td>Nama Pelapor</td>
        <td>Alamat Pelapor</td>
        <td>No Telp Pelapor</td>
        <td>Keterangan Pelapor</td>
        <td>Posko</td>
        <td>Tindakan</td>
        <td>Penyebab</td>
    </tr>
    </thead>
    <tbody>
    ${tbody} 
    </tbody>
    </table>
   `

  var postHtml = `<br>
      <footer>
        <p style="text-align: right; font-size: 10px;">${periode.dayTo}, ${periode.dateToFormat}</p>
        <br>
        <p style="text-align: right; font-size: 10px;">(.........................................)</p>
      </footer></div></body></html>`;

  var html = preHtml + body + postHtml;

  var url =
    "data:application/vnd.ms-word;charset=utf-8," + encodeURIComponent(html);

  filename = filename ? filename + ".doc" : "document.doc";

  var downloadLink = document.createElement("a");

  document.body.appendChild(downloadLink);

  downloadLink.href = url;

  downloadLink.download = filename;

  downloadLink.click();

  document.body.removeChild(downloadLink);
}

export { exportToWord, exportDetailToWord }