import { formatWaktu } from '@/components/Form/FiltersType/reference'

export const exportToWord = (
  rawMeta: any,
  formattedMeta: any,
  rawData: any,
  reportName: String
) => {
  const filename = 'Laporan ' + reportName + '.doc'

  let tbody = ''

  for (let index = 0; index < rawData.length; index++) {
    const element = rawData[index]

    let column = `<tr>`
    let styleTotal = ''

    for (let i = 0; i < element.length; i++) {
      const content = element[i]
      const colSpan = content?.colSpan !== undefined ? `colspan="${content.colSpan}"` : ''

      if (content && (content.content === 'TOTAL' || content.content === 'GRAND TOTAL')) {
        styleTotal = 'style="background-color: #c0c0c0; font-weight: bold;"'
      }

      i === 0
        ? (column += `<th ${styleTotal} ${colSpan} align="left">${content.content}</th>`)
        : (column += `<td ${styleTotal}>${content}</td>`)
    }

    column += `</tr>`
    tbody += column
  }

  let preHtml = `
    <html xmlns:o='urn:schemas-microsoft-com:office:office' xmlns:w='urn:schemas-microsoft-com:office:word' xmlns='http://www.w3.org/TR/REC-html40'>
    <head>
      <meta charset='utf-8'>
      <title>${reportName}</title>
      <style type="text/css" media="print">
        @page Section1 {
          size:841.95pt 21.0cm;
          mso-page-orientation:landscape;
          margin:72.0pt 72.0pt 72.0pt 72.0pt;
          mso-header-margin:35.4pt;
          mso-footer-margin:35.4pt;
          mso-paper-source:0;
        }
    
        div.Section1 {
          page:Section1;
        }

        table.meta tr td {
          text-align: left;
        }

        table.main {
          border-collapse: collapse;
          width: 100%;
          text-transform: uppercase;
          font-size: 8px;
        }

        table.main thead tr {
          background-color: #c0c0c0;
        }
      </style>
    </head>
    <body>
  `

  const body = `
    <div class=Section1>
      <header>
        <h6>PT. PLN(Persero)</h6>

        <table class="meta">
          <tr>
            <td><h6>UNIT INDUK</h6></td>
            <td><h6>:</h6></td>
            <td><h6>${
              rawMeta.uid
                ? rawMeta.uid.name.toUpperCase()
                : 'Semua Unit Induk Distribusi/Wilayah'.toUpperCase()
            }</h6></td>
          </tr>
          <tr>
            <td><h6>UNIT PELAKSANA PELAYANAN PELANGGAN</h6></td>
            <td><h6>:</h6></td>
            <td><h6>${
              rawMeta.up3
                ? rawMeta.up3.name.toUpperCase()
                : 'Semua Unit Pelaksanaan Pelayanan Pelanggan'.toUpperCase()
            }</h6></td>
          </tr>
          <tr>
            <td><h6>UNIT LAYANAN PELANGGAN</h6></td>
            <td><h6>:</h6></td>
            <td><h6>${
              rawMeta.ulp
                ? rawMeta.ulp.name.toUpperCase()
                : 'Semua Unit Layanan Pelanggan'.toUpperCase()
            }</h6></td>
          </tr>
        </table>

        <br>
        <br>
        
        <table width="100%">
          <tr>
            <th><h6>${reportName.toUpperCase()}</h6></th>
          </tr>
          <tr>
            <th><h6>${`PERIODE TANGGAL : ${formattedMeta.dateFromFormat} SD TGL ${formattedMeta.dateToFormat}`}</h6></th>
          </tr>
        </table>
      </header>

      <br>

      <table border="1" class="main">
        <thead>
          <tr>
            <th rowspan="3">No</th>
            <th rowspan="3">Fungsi Bidang</th>
            <th colspan="5">Laporan</th>
            <th colspan="6">Response Time</th>
            <th colspan="6">Penyelesaian</th>
          </tr>
          <tr>
            <th rowspan="2">Total</th>
            <th rowspan="2">%</th>
            <th rowspan="2">Total</th>
            <th rowspan="2">%</th>
            <th rowspan="2">Hari</th>
            <th colspan="4">Laporan</th>
            <th rowspan="2">Hari</th>
            <th colspan="4">Laporan</th>
          </tr>
          <tr>
            <th>Rata-Rata</th>
            <th>Max</th>
            <th>Min</th>
            <th>>Sla</th>
            <th><Sla</th>
            <th>Total</th>
            <th>Rata-Rata</th>
            <th>Max</th>
            <th>Min</th>
            <th>>Sla</th>
            <th><Sla</th>
          </tr>
        </thead>
        <tbody>${tbody}</tbody>
      </table>
      <br>
      <footer>
        <p style="text-align: right; font-size: 10px;">${formattedMeta.dayTo}, ${formattedMeta.dateToFormat}</p>
        <br>
        <p style="text-align: right; font-size: 10px;">(.........................................)</p>
      </footer>
    </div>
  `

  const postHtml = '</body></html>'
  const html = preHtml + body + postHtml
  const url = 'data:application/vnd.ms-word;charset=utf-8,' + encodeURIComponent(html)
  const downloadLink = document.createElement('a')

  document.body.appendChild(downloadLink)
  downloadLink.href = url
  downloadLink.download = filename
  downloadLink.click()
  document.body.removeChild(downloadLink)
}

export const exportDetailToWord = (formattedMeta: any, rawData: any, reportName: String) => {
  const filename = 'Laporan Detail ' + reportName + '.doc'

  let preHtml = `
    <html xmlns:o='urn:schemas-microsoft-com:office:office' xmlns:w='urn:schemas-microsoft-com:office:word' xmlns='http://www.w3.org/TR/REC-html40'>
    <head>
      <meta charset='utf-8'>
      <title>Daftar Detail ${reportName}</title>
      <style type="text/css" media="print">
        @page Section1 {
          size:841.95pt 21.0cm;
          mso-page-orientation:landscape;
          margin:1.0cm 1.0cm 1.0cm 1.0cm;
          mso-header-margin:35.4pt;
          mso-footer-margin:35.4pt;
          mso-paper-source:0;
        }
    
        div.Section1 {
          page:Section1;
        }

        table.meta tr td {
          text-align: left;
        }

        table.main {
          border-collapse: collapse;
          width: 100%;
          text-transform: uppercase;
          font-size: 8px;
        }

        table.main thead tr {
          background-color: #c0c0c0;
        }
      </style>
    </head>
    <body>
  `

  const body = `
    <div class=Section1>
      <header>
        <h6>PT. PLN(Persero)</h6>
        <br>
        <table width="100%">
          <tr>
            <th><h6>${'DAFTAR DETAIL ' + reportName.toUpperCase()}</h6></th>
          </tr>
          <tr>
            <th><h6>${`PERIODE TANGGAL : ${formattedMeta.dateFromFormat} SD TGL ${formattedMeta.dateToFormat}`}</h6></th>
          </tr>
        </table>
      </header>

      <br>

      <table border="1" class="main">
        <thead>
          <tr>
            <th>No</th>
            <th>No Laporan</th>
            <th>Tgl Lapor</th>
            <th>Dalam Proses Bidang</th>
            <th>Selesai Bidang Unit</th>
            <th>Durasi Response Time</th>
            <th>Durasi Recovery Time</th>
            <th>Status</th>
            <th>IDPEL/NO METER</th>
            <th>Nama Pelapor</th>
            <th>Alamat Pelapor</th>
            <th>No Telp Pelapor</th>
            <th>Keterangan Pelapor</th>
            <th>Rayon</th>
            <th>Uraian</th>
            <th>Response Pelanggan</th>          
          </tr>
        </thead>
        <tbody>
          ${rawData.map(
            (item: any, i: any) => `
              <tr>
                <td>${i + 1}</td>
                <td>${item.no_laporan}</td>
                <td>${item.waktu_lapor}</td>
                <td></td>
                <td></td>
                <td>${item.durasi_response_time ? formatWaktu(item.durasi_response_time) : '-'}</td>
                <td>${item.durasi_recovery_time ? formatWaktu(item.durasi_recovery_time) : '-'}</td>
                <td></td>
                <td>${item.idpel_nometer}</td>
                <td>${item.nama_pelapor}</td>
                <td>${item.alamat_pelapor}</td>
                <td>${item.no_telp_pelapor}</td>
                <td>${item.keterangan_pelapor}</td>
                <td></td>
                <td></td>
                <td></td>
              </tr>
            `
          )}
        </tbody>
      </table>
      <br>
      <footer>
        <p style="text-align: right; font-size: 10px;">${formattedMeta.dayTo}, ${formattedMeta.dateToFormat}</p>
        <br>
        <p style="text-align: right; font-size: 10px;">(.........................................)</p>
      </footer>
    </div>
  `

  const postHtml = '</body></html>'
  const html = preHtml + body + postHtml
  const url = 'data:application/vnd.ms-word;charset=utf-8,' + encodeURIComponent(html)
  const downloadLink = document.createElement('a')

  document.body.appendChild(downloadLink)
  downloadLink.href = url
  downloadLink.download = filename
  downloadLink.click()
  document.body.removeChild(downloadLink)
}
