import { exportDataGrid as exportToExcel } from 'devextreme/excel_exporter'
import { saveAs } from 'file-saver'
import { jsPDF } from 'jspdf'
import autoTable from 'jspdf-autotable'
import { Workbook } from 'exceljs'
import { setHeaderStyle } from '@/report/utils/xlsx'
import { formatNumber, formatPercentage } from '@/utils/numbers'
import { getMonthName } from '@/utils/texts'
import { exportToWord } from './doc/MonalisaKR_JumlahDDRPTRCTKeluhan'

const reportName = 'Jumlah dan Durasi RPT RCT Keluhan'
const fontSize = 5

const getGroupParent = (reportMeta: any) => {
  if (reportMeta.ulp.id != 0) {
    return {
      parent: reportMeta.ulp.name,
      summaryName: reportMeta.ulp.name,
      summaryKey: 'nama_ulp'
    }
  }

  if (reportMeta.up3.id != 0) {
    return {
      parent: reportMeta.up3.name,
      summaryName: reportMeta.up3.name,
      summaryKey: 'nama_up3'
    }
  }

  if (reportMeta.uid.id != 0) {
    return {
      parent: reportMeta.uid.name,
      summaryName: reportMeta.uid.name,
      summaryKey: 'nama_uid'
    }
  }

  if (reportMeta.regional.id != 0) {
    return {
      parent: reportMeta.regional.name,
      summaryName: reportMeta.regional.name,
      summaryKey: 'nama_regional'
    }
  }

  return ''
}

const groupingData = (data: any, reportMeta: any) => {
  const groupedData: any = {}
  const groupParent = getGroupParent(reportMeta)

  if (groupParent === '') {
    return {
      data,
      parent: '',
      summaryName: ''
    }
  }

  return {
    data: data,
    parent: groupParent.parent,
    summaryName: groupParent.summaryName
  }
}

const formatData = (rawData: any, reportMeta: any) => {
  const formattedData: any = []

  const total: any = {
    total_durasi_response_time_bulan_ini: 0,
    count_durasi_response_time_bulan_ini: 0,
    total_durasi_recovery_time_bulan_ini: 0,
    count_durasi_recovery_time_bulan_ini: 0,
    total_durasi_response_time_tahun_ini: 0,
    count_durasi_response_time_tahun_ini: 0,
    total_durasi_recovery_time_tahun_ini: 0,
    count_durasi_recovery_time_tahun_ini: 0
  }

  if (reportMeta.regional.id == 0) {
    rawData.forEach((data: any) => {
      total.total_durasi_response_time_bulan_ini += data.total_durasi_response_time_bulan_ini
      total.count_durasi_response_time_bulan_ini += data.count_durasi_response_time_bulan_ini
      total.total_durasi_recovery_time_bulan_ini += data.total_durasi_recovery_time_bulan_ini
      total.count_durasi_recovery_time_bulan_ini += data.count_durasi_recovery_time_bulan_ini
      total.total_durasi_response_time_tahun_ini += data.total_durasi_response_time_tahun_ini
      total.count_durasi_response_time_tahun_ini += data.count_durasi_response_time_tahun_ini
      total.total_durasi_recovery_time_tahun_ini += data.total_durasi_recovery_time_tahun_ini
      total.count_durasi_recovery_time_tahun_ini += data.count_durasi_recovery_time_tahun_ini
    })

    formattedData.push([
      'NASIONAL',
      formatNumber(total.total_durasi_response_time_bulan_ini),
      formatNumber(total.count_durasi_response_time_bulan_ini),
      formatNumber(
        total.total_durasi_response_time_bulan_ini / total.count_durasi_response_time_bulan_ini
      ),
      formatNumber(total.total_durasi_recovery_time_bulan_ini),
      formatNumber(total.count_durasi_recovery_time_bulan_ini),
      formatPercentage(
        total.total_durasi_recovery_time_bulan_ini / total.count_durasi_recovery_time_bulan_ini
      ),
      formatNumber(total.total_durasi_response_time_tahun_ini),
      formatNumber(total.count_durasi_response_time_tahun_ini),
      formatPercentage(
        total.total_durasi_response_time_tahun_ini / total.count_durasi_response_time_tahun_ini
      ),
      formatNumber(total.total_durasi_recovery_time_tahun_ini),
      formatNumber(total.count_durasi_recovery_time_tahun_ini),
      formatPercentage(
        total.total_durasi_recovery_time_tahun_ini / total.count_durasi_recovery_time_tahun_ini
      )
    ])

    return formattedData
  } else {
    const tempData = groupingData(rawData, reportMeta)
    const data = tempData.data[tempData.summaryName] || tempData.data
    const formattedData: any = []

    let parentName = tempData.parent
    let summaryName = tempData.summaryName ? tempData.summaryName : 'Seluruh Unit'

    data.forEach((item: any) => {
      total.total_durasi_response_time_bulan_ini += item.total_durasi_response_time_bulan_ini
      total.count_durasi_response_time_bulan_ini += item.count_durasi_response_time_bulan_ini
      total.total_durasi_recovery_time_bulan_ini += item.total_durasi_recovery_time_bulan_ini
      total.count_durasi_recovery_time_bulan_ini += item.count_durasi_recovery_time_bulan_ini
      total.total_durasi_response_time_tahun_ini += item.total_durasi_response_time_tahun_ini
      total.count_durasi_response_time_tahun_ini += item.count_durasi_response_time_tahun_ini
      total.total_durasi_recovery_time_tahun_ini += item.total_durasi_recovery_time_tahun_ini
      total.count_durasi_recovery_time_tahun_ini += item.count_durasi_recovery_time_tahun_ini
    })

    formattedData.push([
      summaryName,
      formatNumber(total.total_durasi_response_time_bulan_ini),
      formatNumber(total.count_durasi_response_time_bulan_ini),
      formatNumber(
        total.total_durasi_response_time_bulan_ini / total.count_durasi_response_time_bulan_ini
      ),
      formatNumber(total.total_durasi_recovery_time_bulan_ini),
      formatNumber(total.count_durasi_recovery_time_bulan_ini),
      formatPercentage(
        total.total_durasi_recovery_time_bulan_ini / total.count_durasi_recovery_time_bulan_ini
      ),
      formatNumber(total.total_durasi_response_time_tahun_ini),
      formatNumber(total.count_durasi_response_time_tahun_ini),
      formatPercentage(
        total.total_durasi_response_time_tahun_ini / total.count_durasi_response_time_tahun_ini
      ),
      formatNumber(total.total_durasi_recovery_time_tahun_ini),
      formatNumber(total.count_durasi_recovery_time_tahun_ini),
      formatPercentage(
        total.total_durasi_recovery_time_tahun_ini / total.count_durasi_recovery_time_tahun_ini
      )
    ])

    return formattedData
  }
}

const exportToPDF = (reportMeta: any, rawData: any, preview: boolean = false) => {
  const day = new Date().toLocaleString('id-ID', { weekday: 'long' })
  const date = new Date().getDate()
  const month = new Date().toLocaleString('id-ID', { month: 'long' })
  const year = new Date().getFullYear()
  const data = formatData(rawData, reportMeta)
  const doc = new jsPDF({
    orientation: 'landscape'
  })

  autoTable(doc, {
    head: [
      ['PT. PLN(Persero)', '', ''],
      [
        { content: 'UNIT INDUK', styles: { cellWidth: 40 } },
        { content: ':', styles: { cellWidth: 1 } },
        reportMeta.uid
          ? reportMeta.uid.name.toUpperCase()
          : 'Semua Unit Induk Distribusi/Wilayah'.toUpperCase()
      ],
      [
        'UNIT PELAKSANA PELAYANAN PELANGGAN',
        ':',
        reportMeta.up3
          ? reportMeta.up3.name.toUpperCase()
          : 'Semua Unit Pelaksanaan Pelayanan Pelanggan'.toUpperCase()
      ],
      [
        'UNIT LAYANAN PELANGGAN',
        ':',
        reportMeta.ulp
          ? reportMeta.ulp.name.toUpperCase()
          : 'Semua Unit Layanan Pelanggan'.toUpperCase()
      ],
      [
        'REGIONAL',
        ':',
        reportMeta.regional
          ? reportMeta.regional.name.toUpperCase()
          : 'Semua Regional'.toUpperCase()
      ]
    ],
    styles: {
      fontSize,
      cellPadding: 0.1,
      textColor: [0, 0, 0],
      fontStyle: 'bold'
    },
    theme: 'plain',
    startY: 10
  })

  autoTable(doc, {
    head: [[`${reportName}`.toUpperCase()], [reportMeta.periode]],
    styles: {
      fontSize,
      cellPadding: 0.1,
      textColor: [0, 0, 0],
      fontStyle: 'bold',
      halign: 'center'
    },
    theme: 'plain',
    startY: 23
  })

  autoTable(doc, {
    head: [
      [
        {
          content: 'Nama Unit',
          rowSpan: 4
        },
        {
          content: 'Jumlah dan Durasi RPT & RCT Keluhan',
          colSpan: 12
        }
      ],
      [
        {
          content: getMonthName(reportMeta.currentMonth) + ' ' + reportMeta.currentYear,
          colSpan: 6
        },
        {
          content:
            's.d' + ' ' + getMonthName(reportMeta.currentMonth) + ' ' + reportMeta.currentYear,
          colSpan: 6
        }
      ],
      [
        'Total RPT',
        'Jumlah Keluhan',
        'RPT Keluhan',
        'Total RCT',
        'Jumlah Keluhan',
        'RCT Keluhan',
        'Total RPT',
        'Jumlah Keluhan',
        'RPT Keluhan',
        'Total RCT',
        'Jumlah Keluhan',
        'RCT Keluhan'
      ],
      ['a', 'b', 'c=a/b', 'd', 'e', 'f=d/e', 'a', 'b', 'c=a/b', 'd', 'e', 'f=d/e']
    ],
    body: data,
    styles: {
      fontSize,
      cellPadding: 1,
      lineColor: [0, 0, 0],
      lineWidth: 0.1,
      cellWidth: 'auto'
    },
    rowPageBreak: 'auto',
    headStyles: {
      fillColor: [192, 192, 192],
      textColor: [0, 0, 0],
      fontStyle: 'bold',
      cellWidth: 'wrap',
      halign: 'center',
      valign: 'middle'
    },
    bodyStyles: {
      textColor: [0, 0, 0]
    },
    didParseCell: function (data) {
      if (data.row.section === 'head') {
        data.cell.text = data.cell.text.map(function (word: any) {
          return word.toUpperCase()
        })
      }

      if (data.cell.text[0] === 'RATA-RATA') {
        for (const key in data.row.cells) {
          data.row.cells[key].styles.fillColor = [192, 192, 192]
          data.row.cells[key].styles.fontStyle = 'bold'
        }
      }
    },
    startY: 30
  })

  autoTable(doc, {
    head: [
      [`${day}, ${date}-${month}-${year}`],
      [
        {
          content: '(.........................................)',
          styles: { minCellHeight: 8, valign: 'bottom' }
        }
      ]
    ],
    styles: {
      fontSize,
      cellPadding: 0.1,
      textColor: [0, 0, 0],
      fontStyle: 'bold',
      halign: 'center'
    },
    theme: 'plain',
    tableWidth: 50,
    margin: { left: 230 }
  })

  if (preview) {
    doc.setProperties({
      title: `${reportName}`
    })
    window.open(doc.output('bloburl'))
  } else {
    doc.save(`Laporan ${reportName}.pdf`, { returnPromise: true }).then(() => {
      console.log('pdf berhasil disimpan')
    })
  }
}

const exportToXLSX = (reportMeta: any, e: any) => {
  const workbook = new Workbook()
  const worksheet = workbook.addWorksheet(`${reportName}`)

  setHeaderStyle(worksheet, 1, 1, 'PT. PLN(Persero)')
  setHeaderStyle(
    worksheet,
    2,
    1,
    `UNIT INDUK : ${
      reportMeta.uid
        ? reportMeta.uid.name.toUpperCase()
        : 'Semua Unit Induk Distribusi/Wilayah'.toUpperCase()
    }`
  )
  setHeaderStyle(
    worksheet,
    3,
    1,
    `UNIT PELAKSANA PELAYANAN PELANGGAN : ${
      reportMeta.up3
        ? reportMeta.up3.name.toUpperCase()
        : 'Semua Unit Pelaksanaan Pelayanan Pelanggan'.toUpperCase()
    }`
  )
  setHeaderStyle(
    worksheet,
    4,
    1,
    `UNIT LAYANAN PELANGGAN : ${
      reportMeta.ulp
        ? reportMeta.ulp.name.toUpperCase()
        : 'Semua Unit Layanan Pelanggan'.toUpperCase()
    }`
  )
  setHeaderStyle(
    worksheet,
    5,
    1,
    `REGIONAL : ${
      reportMeta.regional ? reportMeta.regional.name.toUpperCase() : 'Semua Regional'.toUpperCase()
    }`
  )

  setHeaderStyle(worksheet, 7, 1, `${reportName}`.toUpperCase(), true)
  setHeaderStyle(worksheet, 8, 1, reportMeta.periode, true)

  worksheet.mergeCells('A1:M1')
  worksheet.mergeCells('A2:M2')
  worksheet.mergeCells('A3:M3')
  worksheet.mergeCells('A4:M4')
  worksheet.mergeCells('A5:M5')
  worksheet.mergeCells('A7:M7')
  worksheet.mergeCells('A8:M8')

  exportToExcel({
    component: e.component,
    worksheet,
    autoFilterEnabled: true,
    topLeftCell: { row: 10, column: 1 },
    loadPanel: {
      enabled: false
    }
  }).then(() => {
    workbook.xlsx.writeBuffer().then((buffer: any) => {
      saveAs(new Blob([buffer], { type: 'application/octet-stream' }), `Laporan ${reportName}.xlsx`)
    })
  })

  e.cancel = true
}

const exportToDOCX = (reportMeta: any, rawData: any) => {
  exportToWord(reportMeta, formatData(rawData, reportMeta), reportName)
}

export { exportToPDF, exportToXLSX, exportToDOCX }
