import { getMonthName } from '@/utils/texts'

export const exportToWord = (rawMeta: any, rawData: any, reportName: String) => {
  const filename = 'Laporan ' + reportName + '.doc'
  const day = new Date().toLocaleString('id-ID', { weekday: 'long' })
  const date = new Date().getDate()
  const month = new Date().toLocaleString('id-ID', { month: 'long' })
  const year = new Date().getFullYear()

  let tbody = ''

  for (let index = 0; index < rawData.length; index++) {
    const element = rawData[index]

    let column = `<tr>`
    let styleTotal = ''

    for (let i = 0; i < element.length; i++) {
      const content = element[i]
      const colSpan = content?.colSpan !== undefined ? `colspan="${content.colSpan}"` : ''

      if (content && (content.content === 'TOTAL' || content.content === 'GRAND TOTAL')) {
        styleTotal = 'style="background-color: #c0c0c0; font-weight: bold;"'
      }

      i === 0
        ? (column += `<th ${styleTotal} ${colSpan} align="left">${content.content || content}</th>`)
        : (column += `<td ${styleTotal}>${content}</td>`)
    }

    column += `</tr>`
    tbody += column
  }

  let preHtml = `
    <html xmlns:o='urn:schemas-microsoft-com:office:office' xmlns:w='urn:schemas-microsoft-com:office:word' xmlns='http://www.w3.org/TR/REC-html40'>
    <head>
      <meta charset='utf-8'>
      <title>${reportName}</title>
      <style type="text/css" media="print">
        @page Section1 {
          size:841.95pt 21.0cm;
          mso-page-orientation:landscape;
          margin:72.0pt 72.0pt 72.0pt 72.0pt;
          mso-header-margin:35.4pt;
          mso-footer-margin:35.4pt;
          mso-paper-source:0;
        }
    
        div.Section1 {
          page:Section1;
        }

        table.meta tr td {
          text-align: left;
        }

        table.main {
          border-collapse: collapse;
          width: 100%;
          text-transform: uppercase;
          font-size: 8px;
        }

        table.main thead tr {
          background-color: #c0c0c0;
        }
      </style>
    </head>
    <body>
  `

  const body = `
    <div class=Section1>
      <header>
        <h6>PT. PLN(Persero)</h6>

        <table class="meta">
          <tr>
            <td><h6>UNIT INDUK</h6></td>
            <td><h6>:</h6></td>
            <td><h6>${
              rawMeta.uid
                ? rawMeta.uid.name.toUpperCase()
                : 'Semua Unit Induk Distribusi/Wilayah'.toUpperCase()
            }</h6></td>
          </tr>
          <tr>
            <td><h6>UNIT PELAKSANA PELAYANAN PELANGGAN</h6></td>
            <td><h6>:</h6></td>
            <td><h6>${
              rawMeta.up3
                ? rawMeta.up3.name.toUpperCase()
                : 'Semua Unit Pelaksanaan Pelayanan Pelanggan'.toUpperCase()
            }</h6></td>
          </tr>
          <tr>
            <td><h6>UNIT LAYANAN PELANGGAN</h6></td>
            <td><h6>:</h6></td>
            <td><h6>${
              rawMeta.ulp
                ? rawMeta.ulp.name.toUpperCase()
                : 'Semua Unit Layanan Pelanggan'.toUpperCase()
            }</h6></td>
          </tr>
          <tr>
            <td><h6>REGIONAL</h6></td>
            <td><h6>:</h6></td>
            <td><h6>${rawMeta.regional.name.toUpperCase()}</h6></td>
          </tr>
        </table>

        <br>
        <br>
        
        <table width="100%">
          <tr>
            <th><h6>${reportName.toUpperCase()}</h6></th>
          </tr>
          <tr>
            <th><h6>${rawMeta.periode}</h6></th>
          </tr>
        </table>
      </header>

      <br>

      <table border="1" class="main">
        <thead>
          <tr>
            <th rowspan="3">No</th>
            <th rowspan="3">Nama Unit</th>
            <th colspan="6">Lapor Ulang Keluhan</th>
          </tr>
          <tr>
            <th colspan="3">MOM</th>
            <th colspan="3">YOY</th>
          </tr>
          <tr>
            <th>${getMonthName(rawMeta.lastMonth)} ${rawMeta.lastYearMoM}</th>
            <th>${getMonthName(rawMeta.currentMonth)} ${rawMeta.currentYear}</th>
            <th>%</th>
            <th>s.d ${getMonthName(rawMeta.currentMonth)} ${rawMeta.lastYear}</th>
            <th>s.d ${getMonthName(rawMeta.currentMonth)} ${rawMeta.currentYear}</th>
            <th>%</th>
          </tr>
        </thead>
        <tbody>${tbody}</tbody>
      </table>
      <br>
      <footer>
        <p style="text-align: right; font-size: 10px;">${day}, ${date}-${month}-${year}</p>
        <br>
        <p style="text-align: right; font-size: 10px;">(.........................................)</p>
      </footer>
    </div>
  `

  const postHtml = '</body></html>'
  const html = preHtml + body + postHtml
  const url = 'data:application/vnd.ms-word;charset=utf-8,' + encodeURIComponent(html)
  const downloadLink = document.createElement('a')

  document.body.appendChild(downloadLink)
  downloadLink.href = url
  downloadLink.download = filename
  downloadLink.click()
  document.body.removeChild(downloadLink)
}
