//deploy vm
import {
  ApolloClient,
  createHttpLink,
  gql,
  InMemoryCache,
  type DocumentNode
} from '@apollo/client/core'
import axios from 'axios'
const controller = new AbortController()
const url = import.meta.env.VITE_APP_GRAPHQL_ENDPOINT
const instance = axios.create({
  baseURL: url,
  headers: {
    Accept: 'application/json',
    'Cache-Control': 'no-cache',
    'Content-Type': 'application/json'
  },
  signal: controller.signal
})

export const getQueryString = (query: DocumentNode) => query.loc?.source.body!

export const requestGraphQl = async (query: DocumentNode, data: any) => {
  return await instance.post('', {
    query: getQueryString(query),
    variables: data
  })
}

export const apolloClient = () => {
  const httpLink = createHttpLink({
    uri: import.meta.env.VITE_APP_GRAPHQL_ENDPOINT,
    credentials: 'include' // Include credentials for cross-origin requests
  })

  const apolloClient = new ApolloClient({
    cache: new InMemoryCache(),
    link: httpLink,
    headers: {
      Accept: 'application/json',
      'Accept-Encoding': 'gzip, deflate',
      'Cache-Control': 'no-cache',
      Connection: 'keep-alive',
      'Content-Type': 'application/json'
      // Add other headers as needed
    }
  })
  return apolloClient
}

export const queries = {
  keluhan: {
    daftar: {
      keluhanSelesaiTanpaIDPelanggan: gql`
        query daftarKeluhanSelesaiTanpaIdPelanggan(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanSelesaiTanpaIdPelanggan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_ulp
            nama_pelapor
            no_laporan
            no_telp_pelapor
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      keluhanDiselesaikanCC123: gql`
        query daftarKeluhanDiselesaikanCC123(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String!
        ) {
          daftarKeluhanDiselesaikanCC123(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
          ) {
            no_laporan
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            status_akhir
            pembuat_laporan
            waktu_lapor
            waktu_recovery
            jumlah_lapor
            media
            nama_issuetype
            nama_subissuetype
          }
        }
      `,
      keluhanResponseTime: gql`
        query daftarKeluhanResponseTime(
          $dateFrom: Date!
          $dateTo: Date!
          $minDurasiResponseTime: Int!
          $maxDurasiResponseTime: Int!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanResponseTime(
            dateFrom: $dateFrom
            dateTo: $dateTo
            minDurasiResponseTime: $minDurasiResponseTime
            maxDurasiResponseTime: $maxDurasiResponseTime
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            nama_ulp
            no_laporan
            no_telp_pelapor
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      keluhanRecoveryTime: gql`
        query daftarKeluhanRecoveryTime(
          $dateFrom: Date!
          $dateTo: Date!
          $minDurasiRecoveryTime: Int!
          $maxDurasiRecoveryTime: Int!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanRecoveryTime(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            minDurasiRecoveryTime: $minDurasiRecoveryTime
            maxDurasiRecoveryTime: $maxDurasiRecoveryTime
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            nama_ulp
            no_laporan
            no_telp_pelapor
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      keluhanMelaporLebihDariSatuKaliDetail: gql`
        query detailKeluhanLaporLebihDariSatuKali($noLaporan: String!) {
          detailKeluhanLaporLebihDariSatuKali(noLaporan: $noLaporan) {
            id
            no_laporan
            create_date
            create_by
            keterangan
          }
        }
      `,
      keluhanMelaporLebihDariSatuKali: gql`
        query daftarKeluhanMelaporLebihDariSatuKali(
          $minJmlLapor: Int!
          $maxJmlLapor: Int!
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanMelaporLebihDariSatuKali(
            dateFrom: $dateFrom
            dateTo: $dateTo
            minJmlLapor: $minJmlLapor
            maxJmlLapor: $maxJmlLapor
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            no_laporan
            waktu_lapor
            waktu_response
            waktu_recovery
            jumlah_lapor
            durasi_response_time
            durasi_recovery_time
            status_akhir
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            media
            nama_ulp
          }
        }
      `,
      keluhanDipindahkanKeIDULPLain: gql`
        query daftarKeluhanDialihkanKeUnitLain(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanDialihkanKeUnitLain(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            id_unit_baru
            id_unit_lama
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            nama_unit_baru
            nama_unit_lama
            no_laporan
            no_telp_pelapor
            pembuat_laporan
            status_akhir
            waktu_dialihkan
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      keluhanBerdasarkanMedia: gql`
        query daftarKeluhanBerdasarkanMedia(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarKeluhanBerdasarkanMedia(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            keterangan_pelapor
            media
            waktu_media
            keterangan_media
            waktu_lapor
            nama_pelapor
            no_laporan
            no_telp_pelapor
            nama_ulp
            status_akhir
            waktu_recovery
            waktu_response
          }
        }
      `
    },
    rekap: {
      keluhanPerRatingUnit: gql`
        query rekapitulasiKeluhanRatingPerUnit(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanRatingPerUnit(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            in_process
            indeks_rating
            jumlah_non_rating
            jumlah_rating
            nama_idUlp
            persen_in_process
            persen_non_rating
            persen_rating
            persen_selesai
            rating_1
            rating_2
            rating_3
            rating_4
            rating_5
            regu
            selesai
            total
          }
        }
      `,
      keluhanPerUnit: gql`
        query rekapitulasiKeluhanPerUnit(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerUnit(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerTanggalULP: gql`
        query rekapitulasiKeluhanPerTanggalUlp(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerTanggalUlp(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            tanggal_lapor
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerTanggalUP3: gql`
        query rekapitulasiKeluhanPerTanggalUp3(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerTanggalUp3(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            tanggal_lapor
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerTanggalUID: gql`
        query rekapitulasiKeluhanPerTanggalUid(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerTanggalUid(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            tanggal_lapor
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerTanggal: gql`
        query rekapitulasiKeluhanPerTanggal(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerTanggal(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            tanggal_lapor
            total
            total_durasi_response
            total_durasi_recovery
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerKelompokKeluhanULP: gql`
        query rekapitulasiKeluhanPerKelompokKeluhanUlp(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerKelompokKeluhanUlp(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            kelompok
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerKelompokKeluhanUP3: gql`
        query rekapitulasiKeluhanPerKelompokKeluhanUp3(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerKelompokKeluhanUp3(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            kelompok
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerKelompokKeluhanUID: gql`
        query rekapitulasiKeluhanPerKelompokKeluhanUid(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerKelompokKeluhanUid(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            kelompok
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerKelompokKeluhan: gql`
        query rekapitulasiKeluhanPerKelompokKeluhan(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerKelompokKeluhan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            kelompok
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_durasi_recovery
            total_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPerJenisKeluhan: gql`
        query rekapitulasiKeluhanPerJenisKeluhan(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPerJenisKeluhan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            grouping_tipe_keluhan
            tipe_keluhan
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPenyelesaianPerFungsiBidangULP: gql`
        query rekapitulasiKeluhanPenyelesaianPerFungsiBidangUlp(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPenyelesaianPerFungsiBidangUlp(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            nama_uid
            nama_up3
            nama_ulp
            fungsi_bidang
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPenyelesaianPerFungsiBidangUP3: gql`
        query rekapitulasiKeluhanPenyelesaianPerFungsiBidangUp3(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPenyelesaianPerFungsiBidangUp3(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            nama_uid
            nama_up3
            nama_ulp
            fungsi_bidang
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPenyelesaianPerFungsiBidangUID: gql`
        query rekapitulasiKeluhanPenyelesaianPerFungsiBidangUid(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPenyelesaianPerFungsiBidangUid(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            nama_uid
            nama_up3
            nama_ulp
            fungsi_bidang
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanPenyelesaianPerFungsiBIidang: gql`
        query rekapitulasiKeluhanPenyelesaianPerFungsiBidang(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanPenyelesaianPerFungsiBidang(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            fungsi_bidang
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      keluhanBerdasarkanMediaDetail: gql`
        query detailRekapitulasiKeluhanBerdasarkanMedia(
          $tanggal: String!
          $idPosko: Int!
          $idUid: Int!
          $idUp3: Int!
          $namaRegional: String
          $media: String
        ) {
          detailRekapitulasiKeluhanBerdasarkanMedia(
            tanggal: $tanggal
            idPosko: $idPosko
            idUid: $idUid
            idUp3: $idUp3
            namaRegional: $namaRegional
            media: $media
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            no_laporan
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_response_time
            durasi_recovery_time
            status_akhir
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            respon_pelanggan
          }
        }
      `,
      rekapKeluhanBerdasarkanMedia: gql`
        query rekapitulasiKeluhanBerdasarkanMedia(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String!
        ) {
          rekapitulasiKeluhanBerdasarkanMedia(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
          ) {
            media
            tgl1
            tgl2
            tgl3
            tgl4
            tgl5
            tgl6
            tgl7
            tgl8
            tgl9
            tgl10
            tgl11
            tgl12
            tgl13
            tgl14
            tgl15
            tgl16
            tgl17
            tgl18
            tgl19
            tgl20
            tgl21
            tgl22
            tgl23
            tgl24
            tgl25
            tgl26
            tgl27
            tgl28
            tgl29
            tgl30
            tgl31
            total
          }
        }
      `,
      rekapKeluhanAll: gql`
        query rekapitulasiKeluhanAll(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiKeluhanAll(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
          }
        }
      `,
      rekapKeluhanAllDetail: gql`
        query detailKeluhanAll(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $namaRegional: String
          $isSelesai: Int!
          $media: String
          $tanggal: String
          $namaIssuetype: String
          $namaSubissuetype: String
        ) {
          detailKeluhanAll(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            namaRegional: $namaRegional
            isSelesai: $isSelesai
            media: $media
            tanggal: $tanggal
            namaIssuetype: $namaIssuetype
            namaSubissuetype: $namaSubissuetype
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            no_laporan
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_response_time
            durasi_recovery_time
            status_akhir
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            respon_pelanggan
            is_selesai
            uraian
          }
        }
      `
    }
  },
  gangguan: {
    rekap: {
      gangguanCleansingTransaksiTMDetail: gql`
        query detailGangguanCleansingTransaksiTM(
          $bulan: Int!
          $tahun: Int!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          detailGangguanCleansingTransaksiTM(
            bulan: $bulan
            tahun: $tahun
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            no_laporan
            tgl_catat
            tgl_pekerjaan
            tgl_nyala
            durasi_pencatatan
            durasi_recovery_time
            keterangan_cleansing
            nama_posko
            tindakan
            penyebab
          }
        }
      `,
      gangguanCleansingTransaksiTM: gql`
        query rekapitulasiGangguanCleansingTransaksiTM(
          $dateFrom: Date!
          $dateTo: Date!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanCleansingTransaksiTM(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            month1
            month2
            month3
            month4
            month5
            month6
            month7
            month8
            month9
            month10
            month11
            month12
          }
        }
      `,
      gangguanRatingPerRegu: gql`
        query rekapitulasiGangguanRatingPerRegu(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanRatingPerRegu(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_regu
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            kode_regu
            nama_regu
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_rating
            persen_rating
            nilai_rating1
            nilai_rating2
            nilai_rating3
            nilai_rating4
            nilai_rating5
            indeks_rating
            total_nonrating
            persen_nonrating
          }
        }
      `,
      gangguanRatingDetail: gql`
        query detailRekapitulasiGangguanBerdasarkanRating(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
          $idRegu: Int!
          $namaRegional: String!
          $isSelesai: Int
          $isNonRating: Int
          $nilaiRating: Int
        ) {
          detailRekapitulasiGangguanBerdasarkanRating(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
            idRegu: $idRegu
            namaRegional: $namaRegional
            isSelesai: $isSelesai
            isNonRating: $isNonRating
            nilaiRating: $nilaiRating
          ) {
            alamat_pelapor
            diselesaikan_oleh
            dispatch_oleh
            durasi_dispatch_time
            durasi_recovery_time
            durasi_response_time
            id
            idpel_nometer
            id_posko
            id_uid
            id_ulp
            id_up3
            is_marking
            is_non_rating
            is_selesai
            jarak_closing
            jenis_gangguan
            keterangan_pelapor
            kode_gangguan
            media
            nama_pelapor
            nama_posko
            nama_regional
            nama_uid
            nama_ulp
            nama_up3
            nilai_rating
            no_laporan
            no_telp_pelapor
            pembuat_laporan
            penyebab
            referensi_marking
            status_akhir
            tindakan
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      gangguanRatingPerPosko: gql`
        query rekapitulasiGangguanRatingPerPosko(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanRatingPerPosko(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_rating
            persen_rating
            nilai_rating1
            nilai_rating2
            nilai_rating3
            nilai_rating4
            nilai_rating5
            indeks_rating
            total_nonrating
            persen_nonrating
          }
        }
      `,
      gangguanPerTanggalPosko: gql`
        query rekapitulasiGangguanPerTanggalPosko(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanPerTanggalPosko(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            tanggal
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
            total_response
            total_recovery
          }
        }
      `,
      gangguanPerTanggalUP3: gql`
        query rekapitulasiGangguanPerTanggalUp3(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanPerTanggalUp3(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            tanggal
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
            total_response
            total_recovery
          }
        }
      `,
      gangguanPerTanggalUID: gql`
        query rekapitulasiGangguanPerTanggalUid(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanPerTanggalUid(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            tanggal
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
            total_response
            total_recovery
          }
        }
      `,
      gangguanPerTanggal: gql`
        query rekapitulasiGangguanPerTanggal(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanPerTanggal(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            avg_durasi_recovery
            avg_durasi_response
            max_durasi_recovery
            max_durasi_response
            min_durasi_recovery
            min_durasi_response
            persen_inproses
            persen_selesai
            tanggal
            total
            total_durasi_response
            total_durasi_recovery
            total_diatas_sla_recovery
            total_diatas_sla_response
            total_dibawah_sla_recovery
            total_dibawah_sla_response
            total_inproses
            total_selesai
          }
        }
      `,
      gangguanPerRegu: gql`
        query rekapitulasiGangguanPerRegu(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanPerRegu(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            id_regu
            kode_regu
            nama_regu
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
            total_response
            total_recovery
          }
        }
      `,
      gangguanPerPosko: gql`
        query rekapitulasiGangguanPerPosko(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanPerPosko(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
            total_response
            total_recovery
          }
        }
      `,
      gangguanKoreksiTransaksiIndividual: gql`
        query rekapitulasiGangguanKoreksiTransaksiIndividual(
          $dateFrom: Date!
          $dateTo: Date!
          $idPosko: Int!
          $idUid: Int!
          $idUp3: Int!
          $is_transaksi_individual: Int!
          $is_cleansing_transaksi_tm: Int!
          $is_koreksi_transaksi_tm: Int!
          $is_koreksi_gangguan_dan_anev: Int!
        ) {
          rekapitulasiGangguanKoreksiTransaksiIndividual(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idPosko: $idPosko
            idUid: $idUid
            idUp3: $idUp3
            is_transaksi_individual: $is_transaksi_individual
            is_cleansing_transaksi_tm: $is_cleansing_transaksi_tm
            is_koreksi_transaksi_tm: $is_koreksi_transaksi_tm
            is_koreksi_gangguan_dan_anev: $is_koreksi_gangguan_dan_anev
          ) {
            nama_regional
            id
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            month1
            month2
            month3
            month4
            month5
            month6
            month7
            month8
            month9
            month10
            month11
            month12
          }
        }
      `,
      gangguanKoreksiTransaksiIndividualDetail: gql`
        query detailGangguanKoreksiTransaksiIndividu(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
          $is_transaksi_individual: Int!
          $is_cleansing_transaksi_tm: Int!
          $is_koreksi_transaksi_tm: Int!
          $is_koreksi_gangguan_dan_anev: Int!
        ) {
          detailGangguanKoreksiTransaksiIndividu(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
            is_transaksi_individual: $is_transaksi_individual
            is_cleansing_transaksi_tm: $is_cleansing_transaksi_tm
            is_koreksi_transaksi_tm: $is_koreksi_transaksi_tm
            is_koreksi_gangguan_dan_anev: $is_koreksi_gangguan_dan_anev
          ) {
            id
            no_laporan
            tgl_lapor
            tgl_lapor_sblm
            tgl_lapor_sdh
            tgl_penugasan_sblm
            tgl_penugasan_sdh
            tgl_perjalanan_sblm
            tgl_perjalanan_sdh
            tgl_pengerjaan_sblm
            tgl_pengerjaan_sdh
            tgl_nyala_sementara_sblm
            tgl_nyala_sementara_sdh
            tgl_nyala_sblm
            tgl_nyala_sdh
            tgl_selesai_sblm
            tgl_selesai_sdh
            durasi_response_time_sblm
            durasi_recovery_time_sblm
            durasi_response_time_sdh
            durasi_recovery_time_sdh
            kelompok_sblm
            kelompok_sdh
            sub_kelompok_sblm
            sub_kelompok_sdh
            fasilitas_id_sblm
            fasilitas_id_sdh
            sub_fasilitas_id_sblm
            sub_fasilitas_id_sdh
            equipment_id_sblm
            equipment_id_sdh
            event_damage_sblm
            event_damage_sdh
            cause_id_sblm
            cause_id_sdh
            cause_group_id_sblm
            cause_group_id_sdh
            weather_id_sblm
            weather_id_sdh
            grup_koreksi
            alasan
            idpel_nometer
            keterangan_pelapor
            nama_posko
            tindakan
            penyebab
          }
        }
      `,
      jenisGangguanSE004: gql`
        query rekapitulasiJenisGangguanSE004(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiJenisGangguanSE004(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            id_fasilitas
            sub_kelompok
            kode
            equipment_id
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_durasi_response
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            total_durasi_recovery
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
            total_response
            total_recovery
          }
        }
      `,
      jenisGangguanSE004Detail: gql`
        query detailGangguanJenisGangguanSE004(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
          $idEquipment: Int!
        ) {
          detailGangguanJenisGangguanSE004(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
            idEquipment: $idEquipment
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            no_laporan
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_response_time
            durasi_recovery_time
            status_akhir
            referensi_marking
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            tindakan
            penyebab
          }
        }
      `,
      jenisGangguan: gql`
        query rekapitulasiPerJenisGangguan(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiPerJenisGangguan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            nama_sub_kelompok
            sub_kelompok
            avg_durasi_recovery
            avg_durasi_response
            max_durasi_recovery
            max_durasi_response
            min_durasi_recovery
            min_durasi_response
            persen_inproses
            persen_selesai
            tipe_permasalahan
            total
            kode
            total_durasi_recovery
            total_durasi_response
            total_diatas_sla_recovery
            total_diatas_sla_response
            total_dibawah_sla_recovery
            total_dibawah_sla_response
            total_inproses
            total_selesai
          }
        }
      `,
      gangguanDiselesaikanMobileAPKT: gql`
        query rekapitulasiGangguanDiselesaikanMobileAPKT(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanDiselesaikanMobileAPKT(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            id_regu
            nama_regu
            kode_regu
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            total_mobile_marking
            total_mobile_nonmarking
            total_nonmobile_marking
            total_nonmobile_nonmarking
            avg_durasi_response_time_mobile_marking
            avg_durasi_response_time_mobile_nonmarking
            avg_durasi_response_time_nonmobile_marking
            avg_durasi_response_time_nonmobile_nonmarking
            avg_durasi_recovery_time_mobile_marking
            avg_durasi_recovery_time_mobile_nonmarking
            avg_durasi_recovery_time_nonmobile_marking
            avg_durasi_recovery_time_nonmobile_nonmarking
          }
        }
      `,
      gangguanDiselesaikanMobileAPKTDetail: gql`
        query detailGangguanDiselesaikanMobileApkt(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
          $idRegu: Int!
        ) {
          detailGangguanDiselesaikanMobileApkt(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
            idRegu: $idRegu
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            no_laporan
            pembuat_laporan
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_dispatch_time
            durasi_response_time
            durasi_recovery_time
            status_akhir
            is_marking
            referensi_marking
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            media
            jarak_closing
            dispatch_oleh
            diselesaikan_oleh
            penyebab
            tindakan
            kode_gangguan
            jenis_gangguan
          }
        }
      `,
      rekapGangguanAlihPosko: gql`
        query rekapitulasiGangguanCleansingTransaksiTM(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanCleansingTransaksiTM(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            agustus
            april
            desember
            februari
            januari
            juli
            juni
            maret
            mei
            november
            oktober
            september
            uid
            ulp
            up3
          }
        }
      `,
      berdasarkanMediaDetail: gql`
        query detailRekapitulasiGangguanBerdasarkanMedia(
          $tanggal: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
          $namaRegional: String!
          $media: String!
        ) {
          detailRekapitulasiGangguanBerdasarkanMedia(
            tanggal: $tanggal
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
            namaRegional: $namaRegional
            media: $media
          ) {
            alamat_pelapor
            diselesaikan_oleh
            dispatch_oleh
            durasi_dispatch_time
            durasi_recovery_time
            durasi_response_time
            id
            id_posko
            id_uid
            id_ulp
            id_up3
            idpel_nometer
            is_marking
            jarak_closing
            jenis_gangguan
            keterangan_pelapor
            kode_gangguan
            media
            nama_pelapor
            nama_posko
            nama_regional
            nama_uid
            nama_ulp
            nama_up3
            nilai_rating
            no_laporan
            no_telp_pelapor
            pembuat_laporan
            penyebab
            referensi_marking
            status_akhir
            tindakan
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      berdasarkanMedia: gql`
        query rekapitulasiGangguanBerdasarkanMedia(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanBerdasarkanMedia(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            media
            total
            tgl1
            tgl10
            tgl11
            tgl12
            tgl13
            tgl14
            tgl15
            tgl16
            tgl17
            tgl18
            tgl19
            tgl2
            tgl20
            tgl21
            tgl22
            tgl23
            tgl24
            tgl25
            tgl26
            tgl27
            tgl28
            tgl29
            tgl3
            tgl30
            tgl31
            tgl4
            tgl5
            tgl6
            tgl7
            tgl8
            tgl9
          }
        }
      `,
      gangguanAll: gql`
        query rekapitulasiAllGangguan(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiAllGangguan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            total
            total_selesai
            persen_selesai
            total_inproses
            persen_inproses
            avg_durasi_dispatch
            min_durasi_dispatch
            max_durasi_dispatch
            total_dibawah_sla_dispatch
            total_diatas_sla_dispatch
            avg_durasi_response
            min_durasi_response
            max_durasi_response
            total_dibawah_sla_response
            total_diatas_sla_response
            avg_durasi_recovery
            min_durasi_recovery
            max_durasi_recovery
            total_dibawah_sla_recovery
            total_diatas_sla_recovery
            count_durasi_dispatch
            count_durasi_response
            count_durasi_recovery
          }
        }
      `,
      gangguanAllDetail: gql`
        query detailGangguan(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
          $idRegu: Int!
          $media: String!
          $idUlp: Int!
          $namaRegional: String!
          $isSelesai: Int!
          $tanggal: String
        ) {
          detailGangguan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
            idRegu: $idRegu
            idUlp: $idUlp
            namaRegional: $namaRegional
            media: $media
            isSelesai: $isSelesai
            tanggal: $tanggal
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            no_laporan
            pembuat_laporan
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_dispatch_time
            durasi_response_time
            durasi_recovery_time
            status_akhir
            is_marking
            referensi_marking
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            media
            nama_posko
            jarak_closing
            dispatch_oleh
            diselesaikan_oleh
            penyebab
            tindakan
            kode_gangguan
            jenis_gangguan
            nilai_rating
          }
        }
      `,
      gangguanAlihPosko: gql`
        query rekapitulasiGangguanAlihPosko(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          rekapitulasiGangguanAlihPosko(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_posko_lama
            id_posko_baru
            id_posko
            id_uid
            id_up3
            nama_posko
            nama_uid
            nama_up3
            posko_in
            posko_out
          }
        }
      `,
      gangguanAlihPoskoDetail: gql`
        query detailGangguanAlihPosko(
          $dateFrom: Date!
          $dateTo: Date!
          $idUid: Int!
          $idUp3: Int!
          $idPoskoBaru: Int!
          $idPoskoLama: Int!
        ) {
          detailGangguanAlihPosko(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUid: $idUid
            idUp3: $idUp3
            idPoskoBaru: $idPoskoBaru
            idPoskoLama: $idPoskoLama
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            no_laporan
            pembuat_laporan
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_response_time
            durasi_recovery_time
            status_akhir
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            media
          }
        }
      `
    },
    daftar: {
      selesaiTanpaIDPelanggan: gql`
        query daftarGangguanSelesaiTanpaIdPelanggan(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarGangguanSelesaiTanpaIdPelanggan(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            no_telp_pelapor
            nama_posko
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      responseTime: gql`
        query daftarGangguanResponseTime(
          $dateFrom: Date!
          $dateTo: Date!
          $minDurasiResponseTime: Int!
          $maxDurasiResponseTime: Int!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarGangguanResponseTime(
            dateFrom: $dateFrom
            dateTo: $dateTo
            minDurasiResponseTime: $minDurasiResponseTime
            maxDurasiResponseTime: $maxDurasiResponseTime
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            penyebab
            referensi_marking
            tindakan
            nama_pelapor
            is_marking
            no_laporan
            no_telp_pelapor
            nama_posko
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      recoveryTime: gql`
        query daftarGangguanRecoveryTime(
          $dateFrom: Date!
          $dateTo: Date!
          $minDurasiRecoveryTime: Int!
          $maxDurasiRecoveryTime: Int!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarGangguanRecoveryTime(
            dateFrom: $dateFrom
            dateTo: $dateTo
            minDurasiRecoveryTime: $minDurasiRecoveryTime
            maxDurasiRecoveryTime: $maxDurasiRecoveryTime
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            referensi_marking
            no_telp_pelapor
            nama_posko
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      melaporLebihDariSatuKaliDetail: gql`
        query detailGangguanLaporLebihDariSatuKali($noLaporan: String!) {
          detailGangguanLaporLebihDariSatuKali(noLaporan: $noLaporan) {
            id
            no_laporan
            create_date
            create_by
            keterangan
          }
        }
      `,
      melaporLebihDariSatuKali: gql`
        query gangguan(
          $minJmlLapor: Int!
          $maxJmlLapor: Int!
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarGangguanMelaporLebihDariSatuKali(
            minJmlLapor: $minJmlLapor
            maxJmlLapor: $maxJmlLapor
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            pembuat_laporan
            durasi_response_time
            durasi_recovery_time
            idpel_nometer
            jumlah_lapor
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            no_telp_pelapor
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
            nama_posko
          }
        }
      `,
      diselesaikanMobileAPKT: gql`
        query daftarGangguanDiselesaikanMobileAPKT(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          daftarGangguanDiselesaikanMobileAPKT(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            no_telp_pelapor
            nama_posko
            status_akhir
            waktu_lapor
            waktu_recovery
            waktu_response
          }
        }
      `,
      dataDialihkanKePoskoLain: gql`
        query DaftarGangguan(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int
          $idUid: Int
          $idUp3: Int
        ) {
          daftarGangguanDialihkanKePoskoLain(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
          ) {
            alamat_pelapor
            pembuat_laporan
            durasi_recovery_time
            durasi_response_time
            waktu_lapor
            waktu_dialihkan
            waktu_recovery
            waktu_response
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            no_telp_pelapor
            nama_posko_lama
            nama_posko_baru
            status_akhir
            waktu_recovery
            waktu_response
          }
        }
      `,
      berdasarkanMedia: gql`
        query daftarGangguanBerdasarkanMedia(
          $dateFrom: Date!
          $dateTo: Date!
          $posko: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String!
        ) {
          daftarGangguanBerdasarkanMedia(
            dateFrom: $dateFrom
            dateTo: $dateTo
            posko: $posko
            idUid: $idUid
            idUp3: $idUp3
            media: $media
          ) {
            alamat_pelapor
            durasi_recovery_time
            durasi_response_time
            idpel_nometer
            keterangan_pelapor
            media
            nama_pelapor
            no_laporan
            no_telp_pelapor
            nama_posko
            status_akhir
            waktu_media
            waktu_lapor
            waktu_recovery
            waktu_response
            keterangan_media
          }
        }
      `
    }
  },
  monalisa: {
    gangguan: {
      rekap: {
        dispatchingTimeGangguanDetailYoy: gql`
          query detailMonalisaDispatchingTimeGangguanYoY(
            $bulan: Int!
            $tahun: Int!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            detailMonalisaDispatchingTimeGangguanYoY(
              bulan: $bulan
              tahun: $tahun
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              id
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              id_posko
              nama_posko
              no_laporan
              pembuat_laporan
              waktu_lapor
              waktu_dispatch
              waktu_response
              waktu_recovery
              durasi_dispatch_time
              durasi_response_time
              durasi_recovery_time
              status_akhir
              is_marking
              referensi_marking
              idpel_nometer
              nama_pelapor
              alamat_pelapor
              no_telp_pelapor
              keterangan_pelapor
              media
              jarak_closing
              dispatch_oleh
              diselesaikan_oleh
              penyebab
              tindakan
              kode_gangguan
              jenis_gangguan
              nilai_rating
            }
          }
        `,
        dispatchingTimeGangguanDetailMom: gql`
          query detailMonalisaDispatchingTimeGangguanMoM(
            $bulan: Int!
            $tahun: Int!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            detailMonalisaDispatchingTimeGangguanMoM(
              bulan: $bulan
              tahun: $tahun
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              id
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              id_posko
              nama_posko
              no_laporan
              pembuat_laporan
              waktu_lapor
              waktu_dispatch
              waktu_response
              waktu_recovery
              durasi_dispatch_time
              durasi_response_time
              durasi_recovery_time
              status_akhir
              is_marking
              referensi_marking
              idpel_nometer
              nama_pelapor
              alamat_pelapor
              no_telp_pelapor
              keterangan_pelapor
              media
              jarak_closing
              dispatch_oleh
              diselesaikan_oleh
              penyebab
              tindakan
              kode_gangguan
              jenis_gangguan
              nilai_rating
            }
          }
        `,
        dispatchingTimeGangguan: gql`
          query monalisaDispatchingTimeGangguan(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaDispatchingTimeGangguan(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        rekapitulasiEnsGangguan: gql`
          query monalisaRekapitulasiEnsGangguan(
            $namaRegional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRekapitulasiEnsGangguan(
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        gangguanBelumSelesaiDetail: gql`
          query detailMonalisaGangguanBelumSelesai(
            $bulan: Int!
            $tahun: Int!
            $namaRegional: String!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            detailMonalisaGangguanBelumSelesai(
              bulan: $bulan
              tahun: $tahun
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              id_pelanggan
              nama_pelanggan
              nama_pelapor
              alamat_pelapor
              no_telp_pelapor
              keterangan_pelapor
              penyebab
              kode_gangguan
              nama_jenis_gangguan
              durasi_response_time
              durasi_recovery_time
            }
          }
        `,
        gangguanBelumSelesai: gql`
          query monalisaGangguanBelumSelesai(
            $bulan: Int!
            $tahun: Int!
            $namaRegional: String!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            monalisaGangguanBelumSelesai(
              bulan: $bulan
              tahun: $tahun
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              jumlah_gangguan
              jumlah_informasi
              total
            }
          }
        `,
        gangguanPerJenisGangguan: gql`
          query monalisaGangguanPerJenisGangguan(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaGangguanPerJenisGangguan(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              id_jenis_gangguan
              nama_jenis_gangguan
              jumlah
              persen
            }
          }
        `,
        jumlahDurasiRptRctGangguan: gql`
          query monalisaJumlahDurasiRptRctGangguan(
            $namaRegional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaJumlahDurasiRptRctGangguan(
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              total_durasi_response_time_bulan_ini
              count_durasi_response_time_bulan_ini
              avg_durasi_response_time_bulan_ini
              total_durasi_recovery_time_bulan_ini
              count_durasi_recovery_time_bulan_ini
              avg_durasi_recovery_time_bulan_ini
              total_durasi_response_time_tahun_ini
              count_durasi_response_time_tahun_ini
              avg_durasi_response_time_tahun_ini
              total_durasi_recovery_time_tahun_ini
              count_durasi_recovery_time_tahun_ini
              avg_durasi_recovery_time_tahun_ini
            }
          }
        `,
        jumlahKaliGangguan: gql`
          query monalisaJumlahKaliGangguan(
            $bulan: Int!
            $tahun: Int!
            $namaRegional: String!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            monalisaJumlahKaliGangguan(
              bulan: $bulan
              tahun: $tahun
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        laporUlangGangguan: gql`
          query monalisaRekapitulasiLaporUlangGangguan(
            $namaRegional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRekapitulasiLaporUlangGangguan(
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        recoveryTimeGangguan: gql`
          query monalisaRecoveryTimeGangguan(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRecoveryTimeGangguan(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        responseTimeGangguan: gql`
          query monalisaResponseTimeGangguan(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaResponseTimeGangguan(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `
      }
    },
    keluhan: {
      rekap: {
        jumlahKaliKeluhan: gql`
          query monalisaJumlahKaliKeluhan(
            $namaRegional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaJumlahKaliKeluhan(
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        recoveryTimeKeluhan: gql`
          query monalisaRecoveryTimeKeluhan(
            $namaRegional: String
            $idUlp: Int
            $idUid: Int
            $idUp3: Int
            $bulan: Int
            $tahun: Int
          ) {
            monalisaRecoveryTimeKeluhan(
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        responseTimeKeluhan: gql`
          query monalisaResponseTimeKeluhan(
            $bulan: Int!
            $tahun: Int!
            $namaRegional: String!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            monalisaResponseTimeKeluhan(
              bulan: $bulan
              tahun: $tahun
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        jumlahDurasiRptRctKeluhan: gql`
          query monalisaJumlahDurasiRptRctKeluhan(
            $bulan: Int!
            $tahun: Int!
            $namaRegional: String!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            monalisaJumlahDurasiRptRctKeluhan(
              bulan: $bulan
              tahun: $tahun
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              total_durasi_response_time_bulan_ini
              count_durasi_response_time_bulan_ini
              avg_durasi_response_time_bulan_ini
              total_durasi_recovery_time_bulan_ini
              count_durasi_recovery_time_bulan_ini
              avg_durasi_recovery_time_bulan_ini
              total_durasi_response_time_tahun_ini
              count_durasi_response_time_tahun_ini
              avg_durasi_response_time_tahun_ini
              total_durasi_recovery_time_tahun_ini
              count_durasi_recovery_time_tahun_ini
              avg_durasi_recovery_time_tahun_ini
            }
          }
        `,
        gangguanPerJenisKeluhan: gql`
          query monalisaGangguanPerJenisKeluhan(
            $bulan: Int!
            $tahun: Int!
            $namaRegional: String!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            monalisaGangguanPerJenisKeluhan(
              bulan: $bulan
              tahun: $tahun
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              id
              id_jenis_keluhan
              nama_jenis_keluhan
              jumlah
              persen
            }
          }
        `,
        laporUlangKeluhan: gql`
          query monalisaRekapitulasiLaporUlangKeluhan(
            $bulan: Int!
            $tahun: Int!
            $namaRegional: String!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            monalisaRekapitulasiLaporUlangKeluhan(
              bulan: $bulan
              tahun: $tahun
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              mom_bulan_ini
              mom_bulan_kemarin
              persen_mom
              yoy_tahun_ini
              yoy_tahun_kemarin
              persen_yoy
            }
          }
        `,
        keluhanBelumSelesaiDetail: gql`
          query detailMonalisaKeluhanBelumSelesai(
            $bulan: Int!
            $tahun: Int!
            $namaRegional: String!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            detailMonalisaKeluhanBelumSelesai(
              bulan: $bulan
              tahun: $tahun
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              id_pelanggan
              nama_pelanggan
              nama_pelapor
              alamat_pelapor
              no_telp_pelapor
              keterangan_pelapor
              penyebab
              kode_gangguan
              nama_subissuetype
              durasi_response_time
              durasi_recovery_time
              no_laporan
              waktu_lapor
            }
          }
        `,
        keluhanBelumSelesai: gql`
          query monalisaRekapitulasiKeluhanBelumSelesai(
            $bulan: Int!
            $tahun: Int!
            $namaRegional: String!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            monalisaRekapitulasiKeluhanBelumSelesai(
              bulan: $bulan
              tahun: $tahun
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              jumlah_keluhan
              jumlah_informasi
              total
            }
          }
        `
      }
    },
    laporan: {
      bulanan: {
        penurunanJumlahKomplainBulanan: gql`
          query penurunanJumlahKomplainBulanan(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            penurunanJumlahKomplainBulanan(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              total_gangguan_tahun_ini
              total_keluhan_tahun_ini
              total_gangguan_informasi_tahun_ini
              total_keluhan_informasi_tahun_ini
              total_informasi_tahun_ini
              total_tahun_ini
              total_gangguan_tahun_sebelumnya
              total_keluhan_tahun_sebelumnya
              total_gangguan_informasi_tahun_sebelumnya
              total_keluhan_informasi_tahun_sebelumnya
              total_informasi_tahun_sebelumnya
              total_tahun_sebelumnya
              delta_gangguan
              delta_keluhan
              delta_informasi
              persen_delta_gangguan
              persen_delta_keluhan
              persen_delta_informasi
              persen_delta_total
            }
          }
        `,
        agingComplaintBulanan: gql`
          query agingComplaintBulanan(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            agingComplaintBulanan(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              avg_durasi_recovery_gangguan
              sla_gangguan
              avg_durasi_recovery_keluhan
              sla_keluhan
              aging_complaint_gangguan
              aging_complaint_keluhan
              avg_aging_complaint
            }
          }
        `,
        energyNotSalesBulanan: gql`
          query energyNotSalesBulanan(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            energyNotSalesBulanan(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              terencana
              tidak_terencana
              bencana_alam
              total
              kpi_ens
            }
          }
        `,
        kepatuhandanAkurasiDalamPelaporanBulanan: gql`
          query kepatuhandanAkurasiDalamPelaporanBulanan(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            kepatuhandanAkurasiDalamPelaporanBulanan(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              gangguan_berulang
              gangguan_total
              keluhan_berulang
              keluhan_total
              komplain_pelanggan
            }
          }
        `,
        kpiBulananGangguanDetail: gql`
          query detailKpiBulananGangguan(
            $bulan: Int!
            $tahun: Int!
            $namaRegional: String!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            detailKpiBulananGangguan(
              bulan: $bulan
              tahun: $tahun
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              no_laporan
              alamat_pelapor
              no_telp_pelapor
              keterangan_pelapor
              penyebab
              kode_gangguan
              jenis_gangguan
              durasi_response_time
              durasi_recovery_time
              waktu_lapor
            }
          }
        `,
        kpiBulananKeluhanDetail: gql`
          query detailKpiBulananKeluhan(
            $bulan: Int!
            $tahun: Int!
            $namaRegional: String!
            $idUlp: Int!
            $idUid: Int!
            $idUp3: Int!
          ) {
            detailKpiBulananKeluhan(
              bulan: $bulan
              tahun: $tahun
              namaRegional: $namaRegional
              idUlp: $idUlp
              idUid: $idUid
              idUp3: $idUp3
            ) {
              id
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              no_laporan
              alamat_pelapor
              no_telp_pelapor
              keterangan_pelapor
              penyebab
              nama_issuetype
              nama_subissuetype
              durasi_response_time
              durasi_recovery_time
              waktu_lapor
            }
          }
        `
      },
      kumulatif: {
        penurunanJumlahKomplainKumulatif: gql`
          query penurunanJumlahKomplainKumulatif(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            penurunanJumlahKomplainKumulatif(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              total_gangguan_tahun_ini
              total_keluhan_tahun_ini
              total_gangguan_informasi_tahun_ini
              total_keluhan_informasi_tahun_ini
              total_informasi_tahun_ini
              total_tahun_ini
              total_gangguan_tahun_sebelumnya
              total_keluhan_tahun_sebelumnya
              total_gangguan_informasi_tahun_sebelumnya
              total_keluhan_informasi_tahun_sebelumnya
              total_informasi_tahun_sebelumnya
              total_tahun_sebelumnya
              delta_gangguan
              delta_keluhan
              delta_informasi
              persen_delta_gangguan
              persen_delta_keluhan
              persen_delta_informasi
              persen_delta_total
            }
          }
        `,
        agingComplaintKumulatif: gql`
          query agingComplaintKumulatif(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            agingComplaintKumulatif(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              avg_durasi_recovery_gangguan
              sla_gangguan
              avg_durasi_recovery_keluhan
              sla_keluhan
              aging_complaint_gangguan
              aging_complaint_keluhan
              avg_aging_complaint
            }
          }
        `,
        energyNotSalesKumulatif: gql`
          query energyNotSalesKumulatif(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            energyNotSalesKumulatif(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              terencana
              tidak_terencana
              bencana_alam
              total
              kpi_ens
            }
          }
        `,
        kepatuhandanAkurasiDalamPelaporanKumulatif: gql`
          query kepatuhandanAkurasiDalamPelaporanKumulatif(
            $namaRegional: String
            $idUid: Int
            $idUp3: Int
            $idUlp: Int
            $bulan: Int
            $tahun: Int
          ) {
            kepatuhandanAkurasiDalamPelaporanKumulatif(
              namaRegional: $namaRegional
              idUid: $idUid
              idUp3: $idUp3
              idUlp: $idUlp
              bulan: $bulan
              tahun: $tahun
            ) {
              nama_regional
              id_uid
              nama_uid
              id_up3
              nama_up3
              id_ulp
              nama_ulp
              gangguan_berulang
              gangguan_total
              keluhan_berulang
              keluhan_total
              komplain_pelanggan
            }
          }
        `
      }
    }
  },
  cico: {
    laporanCheckInCheckOutDetail: gql`
      query detailCheckInCheckOut(
        $dateFrom: Date!
        $dateTo: Date!
        $idPosko: Int!
        $idUid: Int!
        $idUp3: Int!
        $personilYantek: String!
      ) {
        detailCheckInCheckOut(
          dateFrom: $dateFrom
          dateTo: $dateTo
          idPosko: $idPosko
          idUid: $idUid
          idUp3: $idUp3
          personilYantek: $personilYantek
        ) {
          id
          id_uid
          nama_uid
          id_up3
          nama_up3
          id_posko
          nama_posko
          media
          pembuat_laporan
          dispatch_by
          durasi_waktu_dispatch
          user_regu
          nama_regu
          personil_yantek
          shift
          check_in_petugas
          no_laporan
          durasi_wo
          waktu_lapor
          waktu_dispatch
          waktu_perjalanan
          waktu_nyala_sementara
          waktu_nyala
          waktu_selesai
          waktu_response
          durasi_waktu_response
          check_out_petugas
          durasi_menit_response
          durasi_menit_recovery
          rating
          jml_pelanggan_padam
          fasilitas
          sub_fasilitas
          peralatan
          dampak_kerusakan
          kelompok_penyebab
          cuaca
          keterangan_pelapor
          keterangan
          penyebab
          tindakan
          status_akhir
          referensi_marking
          blth
        }
      }
    `,
    laporanCheckInCheckOut: gql`
      query laporanCheckInCheckOut(
        $dateFrom: Date!
        $dateTo: Date!
        $idPosko: Int
        $idUid: Int
        $idUp3: Int
      ) {
        laporanCheckInCheckOut(
          dateFrom: $dateFrom
          dateTo: $dateTo
          idPosko: $idPosko
          idUid: $idUid
          idUp3: $idUp3
        ) {
          id_uid
          id_up3
          id_posko
          user_regu
          personil_yantek
          jumlah_wo_gangguan_individual
          avg_durasi_wo_gangguan_individual
          avg_rpt_wo_gangguan_individual
          avg_rct_wo_gangguan_individual
          jumlah_wo_penugasan_khusus
          avg_wo_penugasan_khusus
        }
      }
    `
  },
  pencarian: {
    pencarianGangguan: gql`
      query pencarianDataReportNumberGangguan(
        $dateFrom: String!
        $dateTo: String!
        $noLaporan: String!
        $namaPelapor: String!
        $noTelpPelapor: String!
        $alamatPelapor: String!
        $pembuatLaporan: String!
      ) {
        pencarianDataReportNumberGangguan(
          dateFrom: $dateFrom
          dateTo: $dateTo
          noLaporan: $noLaporan
          namaPelapor: $namaPelapor
          noTelpPelapor: $noTelpPelapor
          alamatPelapor: $alamatPelapor
          pembuatLaporan: $pembuatLaporan
        ) {
          id
          no_laporan
          idpel_nometer
          nama_pelapor
          alamat_pelapor
          no_telp_pelapor
          status_akhir
          nama_uid
          nama_up3
          nama_ulp
          nama_posko
          id_regu
          waktu_lapor
          waktu_response
          waktu_recovery
          durasi_response_time
          durasi_recovery_time
        }
      }
    `,
    pencarianKeluhan: gql`
      query pencarianDataReportNumberKeluhan(
        $dateFrom: String!
        $dateTo: String!
        $noLaporan: String!
        $namaPelapor: String!
        $noTelpPelapor: String!
        $alamatPelapor: String!
        $pembuatLaporan: String!
      ) {
        pencarianDataReportNumberKeluhan(
          dateFrom: $dateFrom
          dateTo: $dateTo
          noLaporan: $noLaporan
          namaPelapor: $namaPelapor
          noTelpPelapor: $noTelpPelapor
          alamatPelapor: $alamatPelapor
          pembuatLaporan: $pembuatLaporan
        ) {
          id
          no_laporan
          idpel_nometer
          nama_pelapor
          alamat_pelapor
          no_telp_pelapor
          status_akhir
          nama_uid
          nama_up3
          nama_ulp
          nama_posko
          id_regu
          waktu_lapor
          waktu_response
          waktu_recovery
          durasi_response_time
          durasi_recovery_time
        }
      }
    `
  },
  anomali: {
    gangguan: {
      unitBerulangDetail: gql`
        query detailAnomaliPenangananPengaduanGangguanUnitBerulang(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
          $isMarking: Int!
        ) {
          detailAnomaliPenangananPengaduanGangguanUnitBerulang(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
            isMarking: $isMarking
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            no_laporan
            no_laporan_referensi
            referensi_marking
            referensi_marking_induk
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_response_time
            durasi_recovery_time
            durasi_dispatch_time
            durasi_perjalanan
            distance
            dispatch_by
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            media
            diselesaikan_oleh
            status_akhir
            status_induk
            kode_gangguan
            jenis_gangguan
            penyebab
            tindakan
          }
        }
      `,
      unitBerulang: gql`
        query anomaliPenangananPengaduanGangguanUnitBerulang(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          anomaliPenangananPengaduanGangguanUnitBerulang(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            wo_cc123
            wo_pln_mobile
            wo_loket
            wo_lainnya
            wo_total
            anomali_pln_mobile_marking
            anomali_pln_mobile_non_marking
            anomali_cc123_marking
            anomali_cc123_non_marking
            total_anomali_marking
            total_anomali_non_marking
            persen_anomali_pln_mobile_marking
            persen_anomali_pln_mobile_non_marking
            persen_anomali_cc123_marking
            persen_anomali_cc123_non_marking
            persen_anomali_marking
            persen_anomali_non_marking
          }
        }
      `,
      unitRatingNegatifDetail: gql`
        query detailAnomaliPenangananPengaduanGangguanUnitRatingNegatif(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
          $isMarking: Int!
        ) {
          detailAnomaliPenangananPengaduanGangguanUnitRatingNegatif(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
            isMarking: $isMarking
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            no_laporan
            no_laporan_referensi
            referensi_marking
            referensi_marking_induk
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_response_time
            durasi_recovery_time
            durasi_dispatch_time
            durasi_perjalanan
            distance
            dispatch_by
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            media
            diselesaikan_oleh
            status_akhir
            status_induk
            kode_gangguan
            jenis_gangguan
            penyebab
            tindakan
          }
        }
      `,
      unitRatingNegatif: gql`
        query anomaliPenangananPengaduanGangguanUnitRatingNegatif(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          anomaliPenangananPengaduanGangguanUnitRatingNegatif(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            wo_cc123
            wo_pln_mobile
            wo_loket
            wo_lainnya
            wo_total
            anomali_pln_mobile_marking
            anomali_pln_mobile_non_marking
            anomali_cc123_marking
            anomali_cc123_non_marking
            total_anomali_marking
            total_anomali_non_marking
            persen_anomali_pln_mobile_marking
            persen_anomali_pln_mobile_non_marking
            persen_anomali_cc123_marking
            persen_anomali_cc123_non_marking
            persen_anomali_marking
            persen_anomali_non_marking
          }
        }
      `,
      unitSkipStepDetail: gql`
        query detailAnomaliPenangananPengaduanGangguanUnitSkipStep(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
          $isMarking: Int!
        ) {
          detailAnomaliPenangananPengaduanGangguanUnitSkipStep(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
            isMarking: $isMarking
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            no_laporan
            no_laporan_referensi
            referensi_marking
            referensi_marking_induk
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_response_time
            durasi_recovery_time
            durasi_dispatch_time
            durasi_perjalanan
            distance
            dispatch_by
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            media
            diselesaikan_oleh
            status_akhir
            status_induk
            kode_gangguan
            jenis_gangguan
            penyebab
            tindakan
          }
        }
      `,
      unitSkipStep: gql`
        query anomaliPenangananPengaduanGangguanUnitSkipStep(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          anomaliPenangananPengaduanGangguanUnitSkipStep(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            wo_cc123
            wo_pln_mobile
            wo_loket
            wo_lainnya
            wo_total
            anomali_pln_mobile_marking
            anomali_pln_mobile_non_marking
            anomali_cc123_marking
            anomali_cc123_non_marking
            total_anomali_marking
            total_anomali_non_marking
            persen_anomali_pln_mobile_marking
            persen_anomali_pln_mobile_non_marking
            persen_anomali_cc123_marking
            persen_anomali_cc123_non_marking
            persen_anomali_marking
            persen_anomali_non_marking
          }
        }
      `,
      petugasBerulangDetailSub: gql`
        query subDetailAnomaliPenangananPengaduanGangguanPetugasBerulang(
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
          $isMarking: Int!
          $idPetugas: Int!
        ) {
          subDetailAnomaliPenangananPengaduanGangguanPetugasBerulang(
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
            isMarking: $isMarking
            idPetugas: $idPetugas
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            no_laporan
            referensi_marking
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_response_time
            durasi_recovery_time
            durasi_dispatch_time
            durasi_perjalanan
            distance
            dispatch_by
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            media
            diselesaikan_oleh
            status_akhir
            kode_gangguan
            jenis_gangguan
            penyebab
            tindakan
          }
        }
      `,
      petugasBerulangDetail: gql`
        query detailAnomaliPenangananPengaduanGangguanPetugasBerulang(
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
          $isMarking: Int!
        ) {
          detailAnomaliPenangananPengaduanGangguanPetugasBerulang(
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
            isMarking: $isMarking
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            nama_petugas
            nama_unit
            wo_cc123
            wo_pln_mobile
            wo_loket
            wo_total
            wo_lainnya
            anomali_pln_mobile_marking
            anomali_pln_mobile_non_marking
            anomali_cc123_marking
            anomali_cc123_non_marking
            total_anomali_cc123
            total_anomali_pln_mobile
            total_anomali
            persen_anomali_cc123
            persen_anomali_pln_mobile
            persen_anomali
          }
        }
      `,
      petugasBerulang: gql`
        query anomaliPenangananPengaduanGangguanPetugasBerulang(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          anomaliPenangananPengaduanGangguanPetugasBerulang(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            total_petugas
            anomali_pln_mobile_marking
            anomali_pln_mobile_non_marking
            anomali_cc123_marking
            anomali_cc123_non_marking
            total_anomali_marking
            total_anomali_non_marking
            persen_anomali_pln_mobile_marking
            persen_anomali_pln_mobile_non_marking
            persen_anomali_cc123_marking
            persen_anomali_cc123_non_marking
            persen_anomali_marking
            persen_anomali_non_marking
          }
        }
      `,
      petugasRatingNegatifDetailSub: gql`
        query subDetailAnomaliPenangananPengaduanGangguanPetugasRatingNegatif(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
          $isMarking: Int!
          $idPetugas: Int!
        ) {
          subDetailAnomaliPenangananPengaduanGangguanPetugasRatingNegatif(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
            isMarking: $isMarking
            idPetugas: $idPetugas
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            no_laporan
            referensi_marking
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_response_time
            durasi_recovery_time
            durasi_dispatch_time
            durasi_perjalanan
            distance
            dispatch_by
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            media
            diselesaikan_oleh
            status_akhir
            kode_gangguan
            jenis_gangguan
            penyebab
            tindakan
          }
        }
      `,
      petugasRatingNegatifDetail: gql`
        query detailAnomaliPenangananPengaduanGangguanPetugasRatingNegatif(
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
          $isMarking: Int!
        ) {
          detailAnomaliPenangananPengaduanGangguanPetugasRatingNegatif(
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
            isMarking: $isMarking
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            nama_petugas
            nama_unit
            wo_cc123
            wo_pln_mobile
            wo_loket
            wo_total
            wo_lainnya
            anomali_pln_mobile_marking
            anomali_pln_mobile_non_marking
            anomali_cc123_marking
            anomali_cc123_non_marking
            total_anomali_cc123
            total_anomali_pln_mobile
            total_anomali
            persen_anomali_cc123
            persen_anomali_pln_mobile
            persen_anomali
          }
        }
      `,
      petugasRatingNegatif: gql`
        query anomaliPenangananPengaduanGangguanPetugasRatingNegatif(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          anomaliPenangananPengaduanGangguanPetugasRatingNegatif(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            total_petugas
            anomali_pln_mobile_marking
            anomali_pln_mobile_non_marking
            anomali_cc123_marking
            anomali_cc123_non_marking
            total_anomali_marking
            total_anomali_non_marking
            persen_anomali_pln_mobile_marking
            persen_anomali_pln_mobile_non_marking
            persen_anomali_cc123_marking
            persen_anomali_cc123_non_marking
            persen_anomali_marking
            persen_anomali_non_marking
          }
        }
      `,
      petugasSkipStepDetailSub: gql`
        query subDetailAnomaliPenangananPengaduanGangguanPetugasSkipStep(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
          $isMarking: Int!
          $idPetugas: Int!
        ) {
          subDetailAnomaliPenangananPengaduanGangguanPetugasSkipStep(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
            isMarking: $isMarking
            idPetugas: $idPetugas
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            no_laporan
            referensi_marking
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_response_time
            durasi_recovery_time
            durasi_dispatch_time
            durasi_perjalanan
            distance
            dispatch_by
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            media
            diselesaikan_oleh
            status_akhir
            kode_gangguan
            jenis_gangguan
            penyebab
            tindakan
          }
        }
      `,
      petugasSkipStepDetail: gql`
        query detailAnomaliPenangananPengaduanGangguanPetugasSkipStep(
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
          $isMarking: Int!
        ) {
          detailAnomaliPenangananPengaduanGangguanPetugasSkipStep(
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
            isMarking: $isMarking
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            id_posko
            nama_posko
            nama_petugas
            nama_unit
            wo_cc123
            wo_pln_mobile
            wo_loket
            wo_total
            wo_lainnya
            anomali_pln_mobile_marking
            anomali_pln_mobile_non_marking
            anomali_cc123_marking
            anomali_cc123_non_marking
            total_anomali_cc123
            total_anomali_pln_mobile
            total_anomali
            persen_anomali_cc123
            persen_anomali_pln_mobile
            persen_anomali
          }
        }
      `,
      petugasSkipStep: gql`
        query anomaliPenangananPengaduanGangguanPetugasSkipStep(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          anomaliPenangananPengaduanGangguanPetugasSkipStep(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            total_petugas
            anomali_pln_mobile_marking
            anomali_pln_mobile_non_marking
            anomali_cc123_marking
            anomali_cc123_non_marking
            total_anomali_marking
            total_anomali_non_marking
            persen_anomali_pln_mobile_marking
            persen_anomali_pln_mobile_non_marking
            persen_anomali_cc123_marking
            persen_anomali_cc123_non_marking
            persen_anomali_marking
            persen_anomali_non_marking
          }
        }
      `
    },
    keluhan: {
      unitBerulangDetail: gql`
        query detailAnomaliLaporanPenangananPengaduanKeluhanUnitBerulang(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
        ) {
          detailAnomaliLaporanPenangananPengaduanKeluhanUnitBerulang(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            no_laporan
            referensi_marking
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_recovery_time
            durasi_response_time
            status_akhir
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            uraian
            respon_pelanggan
          }
        }
      `,
      unitBerulang: gql`
        query anomaliLaporanPenangananPengaduanKeluhanUnitBerulang(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          anomaliLaporanPenangananPengaduanKeluhanUnitBerulang(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            wo_cc123
            wo_pln_mobile
            wo_loket
            wo_lainnya
            wo_total
            anomali_pln_mobile
            anomali_cc123
            total_anomali
            persen_anomali_pln_mobile
            persen_anomali_cc123
            total_persen_anomali
          }
        }
      `,
      unitSkipStepDetail: gql`
        query detailAnomaliLaporanPenangananPengaduanKeluhanUnitSkipStep(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
        ) {
          detailAnomaliLaporanPenangananPengaduanKeluhanUnitSkipStep(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            no_laporan
            referensi_marking
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_recovery_time
            durasi_response_time
            status_akhir
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            uraian
            respon_pelanggan
          }
        }
      `,
      unitSkipStep: gql`
        query anomaliLaporanPenangananPengaduanKeluhanUnitSkipStep(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          anomaliLaporanPenangananPengaduanKeluhanUnitSkipStep(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            wo_cc123
            wo_pln_mobile
            wo_loket
            wo_lainnya
            wo_total
            anomali_pln_mobile
            anomali_cc123
            total_anomali
            persen_anomali_pln_mobile
            persen_anomali_cc123
            total_persen_anomali
          }
        }
      `,
      unitRatingNegatifDetail: gql`
        query detailAnomaliLaporanPenangananPengaduanKeluhanUnitRatingNegatif(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
          $media: String
        ) {
          detailAnomaliLaporanPenangananPengaduanKeluhanUnitRatingNegatif(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
            media: $media
          ) {
            id
            nama_regional
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            no_laporan
            referensi_marking
            waktu_lapor
            waktu_response
            waktu_recovery
            durasi_recovery_time
            durasi_response_time
            status_akhir
            idpel_nometer
            nama_pelapor
            alamat_pelapor
            no_telp_pelapor
            keterangan_pelapor
            uraian
            respon_pelanggan
          }
        }
      `,
      unitRatingNegatif: gql`
        query anomaliLaporanPenangananPengaduanKeluhanUnitRatingNegatif(
          $dateFrom: Date!
          $dateTo: Date!
          $namaRegional: String!
          $idUlp: Int!
          $idUid: Int!
          $idUp3: Int!
        ) {
          anomaliLaporanPenangananPengaduanKeluhanUnitRatingNegatif(
            dateFrom: $dateFrom
            dateTo: $dateTo
            namaRegional: $namaRegional
            idUlp: $idUlp
            idUid: $idUid
            idUp3: $idUp3
          ) {
            id
            id_uid
            nama_uid
            id_up3
            nama_up3
            id_ulp
            nama_ulp
            wo_cc123
            wo_pln_mobile
            wo_loket
            wo_lainnya
            wo_total
            anomali_pln_mobile
            anomali_cc123
            total_anomali
            persen_anomali_pln_mobile
            persen_anomali_cc123
            total_persen_anomali
          }
        }
      `
    }
  },
  cttKwhPeriksa: {
    laporanCttKwhPeriksa: gql`
      query laporanCttKwhPeriksa(
        $dateFrom: Date!
        $dateTo: Date!
        $idUlp: Int!
        $idUid: Int!
        $idUp3: Int!
        $namaRegional: String
      ) {
        laporanCttKwhPeriksa(
          dateFrom: $dateFrom
          dateTo: $dateTo
          idUlp: $idUlp
          idUid: $idUid
          idUp3: $idUp3
          namaRegional: $namaRegional
        ) {
          id
          id_uid
          nama_uid
          id_up3
          nama_up3
          id_ulp
          nama_ulp
          wo_cc123
          wo_pln_mobile
          wo_comcen
          wo_total
          rekomendasi_mendatangkan_petugas
          rekomendasi_diberikan_ke_pelanggan
          dpld
          history_p2lt
        }
      }
    `,
    laporanCttKwhPeriksaDetail: gql`
      query detailLaporanCttKwhPeriksa(
        $dateFrom: Date!
        $dateTo: Date!
        $tipeWo: Int!
        $rekomendasiSistem: Int!
        $isDlpd: Int!
        $idUlp: Int!
        $idPosko: Int!
        $idUid: Int!
        $idUp3: Int!
        $namaRegional: String
        $isHistoriP2tl: Int!
      ) {
        detailLaporanCttKwhPeriksa(
          dateFrom: $dateFrom
          dateTo: $dateTo
          tipeWo: $tipeWo
          rekomendasiSistem: $rekomendasiSistem
          isDlpd: $isDlpd
          idUlp: $idUlp
          idPosko: $idPosko
          idUid: $idUid
          idUp3: $idUp3
          namaRegional: $namaRegional
          isHistoriP2tl: $isHistoriP2tl
        ) {
          id
          nama_regional
          id_uid
          nama_uid
          id_up3
          nama_up3
          id_ulp
          nama_ulp
          id_pelanggan
          nomormeter
          no_telp_pelapor
          nama_pelapor
          alamat_pelapor
          media
          no_laporan
          r08
          r70
          r71
          r41
          r44
          r45
          r46
          r37
          r47
          jenis_dlpd
          keterangan_dlpd
          blth_dlpd
          no_agenda_p2tl
          tgl_mohon_p2tl
          tgl_sah_p2tl
          rekomendasi_sistem
          waktu_lapor
          petugas_regu
          user_vcc
        }
      }
    `
  },
  material: {
    daftar: {
      daftarGangguanDanMaterialDipakai: gql`
        query DaftardaftarGangguanDanMaterialDipakai(
          $dateFrom: Date!
          $dateTo: Date!
          $idPosko: Int
          $idUid: Int
          $idUp3: Int
        ) {
          daftarGangguanDanMaterialDipakai(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUid: $idUid
            idUp3: $idUp3
            idPosko: $idPosko
          ) {
            id
            no_laporan
            nama_pelapor
            keterangan_pelapor
            penyebab
            waktu_lapor
            waktu_recovery
            regu
            media
            nama_material
            satuan_material
            volume_material
          }
        }
      `
    },
    rekap: {
      rekapitulasiPemakaianMaterial: gql`
        query DaftarrekapitulasiPemakaianMaterial(
          $dateFrom: Date!
          $dateTo: Date!
          $idPosko: Int
          $idUid: Int
          $idUp3: Int
        ) {
          rekapitulasiPemakaianMaterial(
            dateFrom: $dateFrom
            dateTo: $dateTo
            idUid: $idUid
            idUp3: $idUp3
            idPosko: $idPosko
          ) {
            id
            kode
            nama_material
            satuan
            sumber_material
            tgl1
            tgl10
            tgl11
            tgl12
            tgl13
            tgl14
            tgl15
            tgl16
            tgl17
            tgl18
            tgl19
            tgl2
            tgl20
            tgl21
            tgl22
            tgl23
            tgl24
            tgl25
            tgl26
            tgl27
            tgl28
            tgl29
            tgl3
            tgl30
            tgl31
            tgl4
            tgl5
            tgl6
            tgl7
            tgl8
            tgl9
            total
          }
        }
      `
    }
  },
  transaksi: {
    transaksiAPKT: gql`
      query transaksiApkt(
        $dateFrom: Date!
        $dateTo: Date!
        $idPosko: Int!
        $idUlp: Int!
        $idUid: Int!
        $idUp3: Int!
        $tipe_sla: Int!
        $operator_sla: String!
        $status_akhir: String!
        $no_laporan: String!
        $nama_pelapor: String!
        $permasalahan: String!
        $tipe_laporan: String!
      ) {
        transaksiApkt(
          dateFrom: $dateFrom
          dateTo: $dateTo
          idPosko: $idPosko
          idUlp: $idUlp
          idUid: $idUid
          idUp3: $idUp3
          tipe_sla: $tipe_sla
          operator_sla: $operator_sla
          status_akhir: $status_akhir
          no_laporan: $no_laporan
          nama_pelapor: $nama_pelapor
          permasalahan: $permasalahan
          tipe_laporan: $tipe_laporan
        ) {
          no_laporan
          issuetype
          nama_pelapor
          nama_ulp
          no_telp_pelapor
          permasalahan
          deskripsi
          waktu_lapor
          jumlah_lapor
          keterangan_lapor_ulang
          status_akhir
          durasi
          tipe_sla
          operator_sla
          is_sla
        }
      }
    `
  }
}
